@@ -16,7 +16,7 @@ for(d in Ext.elCache)Ext.EventManager.removeAll(d);delete Ext.elCache;delete Ext
 F&&j()||r.addEventListener(z,h,false);else Ext.isWebKit&&f();u.on(B,"load",n)}e=e||{};e.delay=e.delay||1;s.addListener(d,g,e)}},fireDocReady:n};v.on=v.addListener;v.un=v.removeListener;v.stoppedMouseDownEvent=new Ext.util.Event;return v}())})();(function(){Ext.apply(Ext.EventObjectImpl.prototype,{SEMI_COLON:186,EQUAL_SIGN:187,COMMA:188,DASH:189,PERIOD:190,FORWARD_SLASH:191,OPEN_BRACKET:219,BACK_SLASH:220,CLOSE_BRACKET:221,SINGLE_QUOTE:222})})();
 (function(){Ext.apply(Ext.Fx,{fxUnwrap:function(a,b,c){var f=this.dom;Ext.fly(f).clearPositioning();Ext.fly(f).setPositioning(b);if(!c.wrap)if(b=Ext.fly(a).dom.parentNode){b.insertBefore(f,a);Ext.fly(a).remove()}}});Ext.Element.addMethods(Ext.Fx)})();
 (function(){var a=Ext.TabPanel.prototype.onStripMouseDown;Ext.override(Ext.TabPanel,{itemTpl:new Ext.Template('<li class="{cls}" id="{id}">','<a href="#" class="x-tab-strip-focus"></a>','<a class="x-tab-strip-close"></a>','<a class="x-tab-right">','<em class="x-tab-left">','<span class="x-tab-strip-inner">','<span class="x-tab-strip-text {iconCls}">{text}</span>',"</span>","</em>","</a>","</li>",{disableFormats:true,compiled:true}),onStripMouseDown:function(b){var c=new Ext.EventObjectImpl(b);b=this.findTargets(b);
-if(b.el)(b=Ext.get(b.el).child("a.x-tab-strip-focus"))&&b.focus();a.call(this,c)}})})();(function(){var a=Ext.Toolbar.TextItem.prototype.onRender;Ext.override(Ext.Toolbar.TextItem,{onRender:function(){a.apply(this,arguments);this.el&&this.el.unselectable()}})})();
+if(b.el)(b=Ext.get(b.el).child("a.x-tab-strip-focus"))&&b.focus();a.call(this,c)}})})();(function(){var a=Ext.Tip.prototype.doAutoWidth;Ext.override(Ext.Tip,{doAutoWidth:function(){a.call(this,Ext.isIE?1:0)}})})();(function(){var a=Ext.Toolbar.TextItem.prototype.onRender;Ext.override(Ext.Toolbar.TextItem,{onRender:function(){a.apply(this,arguments);this.el&&this.el.unselectable()}})})();
 (function(){var a=Ext.data.Node.prototype.appendChild,b=Ext.data.Node.prototype.removeChild;Ext.override(Ext.data.Node,{appendChild:function(){this.leaf=false;return a.apply(this,arguments)},removeChild:function(){var c=b.apply(this,arguments);if(!this.hasChildNodes())this.leaf=true;return c}})})();
 (function(){var a=function(b){return b!==undefined&&b!==null&&b!==""?parseInt(b,10):this.useNull?null:0};Ext.data.Types.INT.convert=a;Ext.data.Types.INTEGER.convert=a;a=function(b){return b!==undefined&&b!==null&&b!==""?parseFloat(b,10):this.useNull?null:0};Ext.data.Types.FLOAT.convert=a;Ext.data.Types.NUMBER.convert=a})();Ext.override(Ext.dd.DD,{scroll:false});(function(){Ext.apply(Ext.dd.DragDropMgr,{getGroupDDById:function(a,b){if(this.ids[a]&&this.ids[a][b])return this.ids[a][b];return null}})})();
 (function(){var a=Ext.dd.DragSource.prototype.onDragOver,b=Ext.dd.DragSource.prototype.onDragOut,c=Ext.dd.DragSource.prototype.onDragDrop;Ext.override(Ext.dd.DragSource,{onDragEnter:function(f,j){this.cachedTarget&&this.onDragOut(f,this.cachedTarget.id);var h;if((this.cachedTarget=h=this.ddGroup?Ext.dd.DragDropMgr.getGroupDDById(this.ddGroup,j):Ext.dd.DragDropMgr.getDDById(j))&&this.beforeDragEnter(h,f,j)!==false){h.isNotifyTarget?this.proxy.setStatus(h.notifyEnter(this,f,this.dragData)):this.proxy.setStatus(this.dropAllowed);
@@ -30,8 +30,8 @@ j.el.dom.value){j.setValue(f.value);if(this.trackResetOnLoad)j.originalValue=j.g
 c.getKey(),j=this.getDoc(),h;if(f==c.TAB){c.stopEvent();f=this.win.getSelection();if(f.getRangeAt&&f.rangeCount){h=f.getRangeAt(0);h.deleteContents();c=j.createElement("div");c.innerHTML="&nbsp;&nbsp;&nbsp;&nbsp;";j=j.createDocumentFragment();for(var n,t;n=c.firstChild;)t=j.appendChild(n);h.insertNode(j);if(t){h=h.cloneRange();h.setStartAfter(t);h.collapse(true);f.removeAllRanges();f.addRange(h)}}this.deferFocus()}else if(f==c.ENTER){f=this.win.getSelection();if(f.getRangeAt&&f.rangeCount){h=f.getRangeAt(0);
 h.deleteContents();n=h.commonAncestorContainer;if(!n||n.nodeName.toLowerCase()!="li"&&n.parentNode.nodeName.toLowerCase()!="li"){c.stopEvent();c=j.createElement("div");c.innerHTML="<br />";for(j=j.createDocumentFragment();n=c.firstChild;)t=j.appendChild(n);h.insertNode(j);if(t){h=h.cloneRange();h.setStartAfter(t);h.collapse(false);f.removeAllRanges();f.addRange(h)}}}}};else if(Ext.isOpera)return function(c){if(c.getKey()==c.TAB){c.stopEvent();this.win.focus();this.execCmd("InsertHTML","&nbsp;&nbsp;&nbsp;&nbsp;");
 this.deferFocus()}};else if(Ext.isWebKit)return function(c){if(c.getKey()==c.TAB){c.stopEvent();this.execCmd("InsertText","\t");this.deferFocus()}}}(),initEditor:function(){b.apply(this,arguments);this.getWin().addEventListener("dragover",Zarafa.onWindowDragDrop,false);this.getWin().addEventListener("drop",Zarafa.onWindowDragDrop,false)}})})();
-(function(){var a=Ext.form.Label.prototype.onRender;Ext.override(Ext.form.Label,{cls:"x-form-item-label",onRender:function(){a.apply(this,arguments);this.positionEl=this.el.wrap({cls:"x-form-item"});this.el.unselectable()}})})();(function(){var a=Ext.grid.GridPanel.prototype.onClick;Ext.override(Ext.grid.GridPanel,{onClick:function(){a.apply(this,arguments);this.view.focusEl.focus()}})})();
-(function(){Ext.override(Ext.grid.GridView,{getColumnWidth:function(a){a=this.cm.getColumnWidth(a);var b=this.borderWidth;return Ext.isNumber(a)?Ext.isBorderBox?a+"px":Math.max(a-b,0)+"px":a}})})();(function(){if(Ext.isIE6||Ext.isIE7||Ext.isAir)Ext.BLANK_IMAGE_URL="client/resources/images/s.gif";var a=Ext.encode;Ext.encode=Ext.util.JSON.encode=function(b){if(Ext.isDefined(b))return a(b)}})();
+(function(){var a=Ext.form.Label.prototype.onRender;Ext.override(Ext.form.Label,{cls:"x-form-item-label",onRender:function(){a.apply(this,arguments);this.positionEl=this.el.wrap({cls:"x-form-item"});this.el.unselectable()}})})();(function(){var a=/^(100?|\d?\d)?%?$/;Ext.apply(Ext.form.VTypes,{percentage:function(b){return a.test(b)},percentageText:_("Value must be between 0% to 100%")})})();
+(function(){var a=Ext.grid.GridPanel.prototype.onClick;Ext.override(Ext.grid.GridPanel,{onClick:function(){a.apply(this,arguments);this.view.focusEl.focus()}})})();(function(){Ext.override(Ext.grid.GridView,{getColumnWidth:function(a){a=this.cm.getColumnWidth(a);var b=this.borderWidth;return Ext.isNumber(a)?Ext.isBorderBox?a+"px":Math.max(a-b,0)+"px":a}})})();
 (function(){var a=Ext.layout.BorderLayout.Region.prototype.beforeCollapse,b=Ext.layout.BorderLayout.Region.prototype.onExpand;Ext.override(Ext.layout.BorderLayout.Region,{beforeCollapse:function(){this.splitEl&&this.splitEl.addClass("x-hide-display");a.apply(this,arguments)},onExpand:function(){this.splitEl&&this.splitEl.removeClass("x-hide-display");b.apply(this,arguments)}})})();
 (function(){var a=Ext.layout.ToolbarLayout.prototype.configureItem,b=Ext.layout.ToolbarLayout.prototype.hideItem,c=Ext.layout.ToolbarLayout.prototype.unhideItem,f=Ext.layout.ToolbarLayout.prototype.onLayout,j=Ext.layout.ToolbarLayout.prototype.addComponentToMenu;Ext.override(Ext.layout.ToolbarLayout,{triggerWidth:41,overflowTabIndex:undefined,onLayout:function(h){f.apply(this,arguments);h.items.each(function(n){Ext.isFunction(n.doLayout)&&n.doLayout()},this);this.overflowTabIndex&&this.more&&Ext.get(this.more.el).child("button").set({tabIndex:this.overflowTabIndex})},
 configureItem:function(h){var n=this.container,t=n.getLayoutTarget();a.apply(this,arguments);h.on("show",function(w){w.xtbHidden!==true&&this.onLayout(n,t)},this);h.on("hide",function(w){w.xtbHidden!==true&&this.onLayout(n,t)},this)},hideItem:function(h){var n=this;b.apply(this,arguments);h.xtbOrigShow=h.show;h.show=function(){h.xtbOrigShow(true);h.xtbWidth=h.getPositionEl().dom.parentNode.offsetWidth;h.xtbOrigHide(false)};h.xtbOrigHide=h.hide;h.hide=function(){n.unhideItem(h);h.hide()}},unhideItem:function(h){h.show=
@@ -42,7 +42,7 @@ h.xtbOrigShow;delete h.xtbOrigShow;h.hide=h.xtbOrigHide;delete h.xtbOrigHide;del
 "{0} TB",a),a)},percentage:function(a,b){Ext.isDefined(b)||(b=2);return(a*100).toFixed(b)+"%"},duration:function(a,b){b=Ext.isDefined(b)?b:0;if(a<60)return String.format(ngettext("{0} minute","{0} minutes",a),a);a=parseFloat((a/60).toFixed(b));if(a<24)return String.format(ngettext("{0} hour","{0} hours",a),a);a=parseFloat((a/24).toFixed(b));if(a<7)return String.format(ngettext("{0} day","{0} days",a),a);a=parseFloat((a/7).toFixed(b));return String.format(ngettext("{0} week","{0} weeks",a),a)},indent:function(a,
 b){for(var c=(Ext.isDefined(a)?a:1)*(Ext.isDefined(b)?b:4),f="",j=0;j<c;j++)f+="&nbsp;";return f},elide:function(a,b,c){b=b||0;c=Ext.isDefined(c)?c:b;if(b===0&&c===0)return a;if(a&&a.length>b+c)return a.substr(0,b)+"..."+a.substr(a.length-c);return a},htmlEncodeUndef:function(){return this.htmlEncode(this.undef.apply(this,arguments))},defaultValue:function(a,b){return Ext.value(a,b)},htmlEncodeDefaultValue:function(){return this.htmlEncode(this.defaultValue.apply(this,arguments))},htmlEncodeElide:function(){return this.htmlEncode(this.elide.apply(this,
 arguments))},htmlEncodeEllipsis:function(){return this.htmlEncode(this.ellipsis.apply(this,arguments))},basename:function(a){return a.split("\\").pop()},htmlEncodeBasename:function(){return this.htmlEncode(this.basename.apply(this,arguments))},sensitivityString:function(a){return Zarafa.core.mapi.Sensitivity.getDisplayName(a)},importanceString:function(a){return Zarafa.core.mapi.Importance.getDisplayName(a)},meetingStatusString:function(a){return Zarafa.core.mapi.MeetingStatus.getDisplayName(a)},
-responseStatusString:function(a){return Zarafa.core.mapi.ResponseStatus.getDisplayName(a)},taskStatusString:function(a){return Zarafa.core.mapi.TaskStatus.getDisplayName(a)}})})();
+responseStatusString:function(a){return Zarafa.core.mapi.ResponseStatus.getDisplayName(a)},taskStatusString:function(a){return Zarafa.core.mapi.TaskStatus.getDisplayName(a)},busyStatusString:function(a){return Zarafa.core.mapi.BusyStatus.getDisplayName(a)}})})();
 (function(){Ext.override(Ext.ux.Spinner,{initSpinner:function(){this.field.addEvents({spin:true,spinup:true,spindown:true});this.keyNav=new Ext.KeyNav(this.el,{up:function(a){a.preventDefault();this.onSpinUp()},down:function(a){a.preventDefault();this.onSpinDown()},pageUp:function(a){a.preventDefault();this.onSpinUpAlternate()},pageDown:function(a){a.preventDefault();this.onSpinDownAlternate()},scope:this});this.field.mon(this.trigger,"click",this.onTriggerClick,this,{preventDefault:true});this.field.mon(this.trigger,
 {mouseover:this.onMouseOver,mouseout:this.onMouseOut,mousemove:this.onMouseMove,mousedown:this.onMouseDown,mouseup:this.onMouseUp,scope:this,preventDefault:true});this.field.mon(this.wrap,"mousewheel",this.handleMouseWheel,this);this.dd.setXConstraint(0,0,10);this.dd.setYConstraint(1500,1500,10);this.dd.endDrag=this.endDrag.createDelegate(this);this.dd.startDrag=this.startDrag.createDelegate(this);this.dd.onDrag=this.onDrag.createDelegate(this)}})})();
 (function(){Ext.override(Ext.ux.grid.CheckColumn,{onMouseDown:function(a,b){if(Ext.fly(b).hasClass(this.createId())){a.stopEvent();var c=this.grid.store.getAt(this.grid.getView().findRowIndex(b));c.set(this.dataIndex,!c.data[this.dataIndex]);c.save()}}})})();Ext.namespace("Zarafa.util");
