@@ -41,11 +41,11 @@
 				<div id="login_main">
 					<form action="index.php?logon<?=($user)?'&user='.$user:''?>" method="post">
 						<div id="login_data">
-							<p><?=!(isset($_SESSION) && isset($_SESSION["hresult"]))?_("Please logon"):"&nbsp;"?></p>
+							<p><?=!(isset($GLOBALS["hresult"]))?_("Please logon"):"&nbsp;"?></p>
 							<p class="error"><?php
 
-	if (isset($_SESSION) && isset($_SESSION["hresult"])) {
-		switch($_SESSION["hresult"]){
+	if (isset($GLOBALS["hresult"])) {
+		switch($GLOBALS["hresult"]){
 			case MAPI_E_LOGON_FAILED:
 			case MAPI_E_UNCONFIGURED:
 				echo _("Logon failed, please check your name/password.");
@@ -53,10 +53,13 @@
 			case MAPI_E_NETWORK_ERROR:
 				echo _("Cannot connect to the zarafa server.");
 				break;
+			case MAPI_E_INVALID_WORKSTATION_ACCOUNT:
+				echo _("Logon failed, another session already exists.");
+				break;
 			default:
-				echo "Unknown MAPI Error: ".get_mapi_error_name($_SESSION["hresult"]);
+				echo "Unknown MAPI Error: ".get_mapi_error_name($GLOBALS["hresult"]);
 		}
-		unset($_SESSION["hresult"]);
+		unset($GLOBALS["hresult"]);
 	}else if (isset($_GET["logout"]) && $_GET["logout"]=="auto"){
 		echo _("You have been automatically logged out");
 	}else{
