@@ -21,4 +21,4 @@ var a;this.switches=[];for(var b=0;b<this.moves;b++){for(a=[];a.length<2;){var c
 a.setStyle("z-index",this.cupShuffleZIndexFront);b.shift({y:this.topLeftContainerOffset.y+this.topOffset-this.shuffleMoveOffset,concurrent:false,duration:this.moveCupToFrontDuration});a.shift({y:this.topLeftContainerOffset.y+this.topOffset+this.shuffleMoveOffset,concurrent:false,duration:this.moveCupToFrontDuration});b.shift({callback:function(d){d.setStyle("z-index",this.cupZIndex)}.createDelegate(this),x:this.topLeftContainerOffset.x+e[0],concurrent:false,duration:this.moveDuration});a.shift({callback:function(d){d.setStyle("z-index",
 this.cupZIndex)}.createDelegate(this),x:this.topLeftContainerOffset.x+c[0],concurrent:false,duration:this.moveDuration});b.shift({y:this.topLeftContainerOffset.y+this.topOffset,concurrent:false,duration:this.moveCupToFrontDuration});a.shift({callback:this.shuffleStep.createDelegate(this),y:this.topLeftContainerOffset.y+this.topOffset,concurrent:false,duration:this.moveCupToFrontDuration});c=b.positionIndex;b.positionIndex=a.positionIndex;a.positionIndex=c}},onShuffleEnd:function(){this.changeState(Zarafa.widgets.shellgame.ShellGameStates.GUESS);
 this.ownerCt.instructionLabel.setText(this.pickYourCupSentence)},onEndGame:function(){this.changeState(Zarafa.widgets.shellgame.ShellGameStates.IDLE)},changeState:function(a){this.state=a;this.fireEvent("statechange",this,this.state)}});Ext.reg("zarafa.widget.shellgame.playfieldpanel",Zarafa.widgets.shellgame.ShellGamePlayFieldPanel);Ext.namespace("Zarafa.widgets.shellgame");Zarafa.widgets.shellgame.ShellGameStates={IDLE:1,SHUFFLE:2,GUESS:3,SHOW:4};Ext.namespace("Zarafa.widgets.shellgame");
-Zarafa.widgets.shellgame.ShellGameWidget=Ext.extend(Zarafa.core.ui.widget.Widget,{constructor:function(a){a=a||{};Ext.applyIf(a,{name:"shellgamewidget",title:_("Shell Game"),height:350,items:[{xtype:"zarafa.widget.shellgamepanel"}]});Zarafa.widgets.shellgame.ShellGameWidget.superclass.constructor.call(this,a)}});Zarafa.onReady(function(){container.registerWidget(Zarafa.widgets.shellgame.ShellGameWidget,"shellgame",_("Shell Game"),"plugins/shellgame/resources/images/shellgame.png")});
+Zarafa.widgets.shellgame.ShellGameWidget=Ext.extend(Zarafa.core.ui.widget.Widget,{constructor:function(a){a=a||{};Ext.applyIf(a,{height:350,items:[{xtype:"zarafa.widget.shellgamepanel"}]});Zarafa.widgets.shellgame.ShellGameWidget.superclass.constructor.call(this,a)}});Zarafa.onReady(function(){container.registerWidget(new Zarafa.core.ui.widget.WidgetMetaData({name:"shellgame",displayName:_("Shell Game"),iconPath:"plugins/shellgame/resources/images/shellgame.png",widgetConstructor:Zarafa.widgets.shellgame.ShellGameWidget}))});
