@@ -1,36 +1,52 @@
 <?php
-//
-// +----------------------------------------------------------------------+
-// | PHP Version 4                                                        |
-// +----------------------------------------------------------------------+
-// | Copyright (c) 1997-2004 The PHP Group                                |
-// +----------------------------------------------------------------------+
-// | This source file is subject to version 3.0 of the PHP license,       |
-// | that is bundled with this package in the file LICENSE, and is        |
-// | available at through the world-wide-web at                           |
-// | http://www.php.net/license/3_0.txt.                                  |
-// | If you did not receive a copy of the PHP license and are unable to   |
-// | obtain it through the world-wide-web, please send a note to          |
-// | license@php.net so we can mail you a copy immediately.               |
-// +----------------------------------------------------------------------+
-// | Author: Stig Bakken <ssb@fast.no>                                    |
-// |         Tomas V.V.Cox <cox@idecnet.com>                              |
-// |         Stephan Schmidt <schst@php-tools.net>                        |
-// +----------------------------------------------------------------------+
-//
-// $Id: Parser.php,v 1.26 2005/09/23 11:51:10 schst Exp $
+
+/* vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4: */
 
 /**
- * XML Parser class.
+ * XML_Parser
  *
- * This is an XML parser based on PHP's "xml" extension,
- * based on the bundled expat library.
+ * XML Parser package
  *
- * @category XML
- * @package XML_Parser
- * @author  Stig Bakken <ssb@fast.no>
- * @author  Tomas V.V.Cox <cox@idecnet.com>
- * @author  Stephan Schmidt <schst@php-tools.net>
+ * PHP versions 4 and 5
+ *
+ * LICENSE:
+ *
+ * Copyright (c) 2002-2008 The PHP Group
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
+ *
+ *    * Redistributions of source code must retain the above copyright
+ *      notice, this list of conditions and the following disclaimer.
+ *    * Redistributions in binary form must reproduce the above copyright
+ *      notice, this list of conditions and the following disclaimer in the
+ *      documentation and/or other materials provided with the distribution.
+ *    * The name of the author may not be used to endorse or promote products
+ *      derived from this software without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
+ * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
+ * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
+ * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
+ * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
+ * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
+ * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
+ * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
+ * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
+ * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
+ * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+ *
+ * @category  XML
+ * @package   XML_Parser
+ * @author    Stig Bakken <ssb@fast.no>
+ * @author    Tomas V.V.Cox <cox@idecnet.com>
+ * @author    Stephan Schmidt <schst@php.net>
+ * @copyright 2002-2008 The PHP Group
+ * @license   http://opensource.org/licenses/bsd-license New BSD License
+ * @version   CVS: $Id: Parser.php 302733 2010-08-24 01:09:09Z clockwerx $
+ * @link      http://pear.php.net/package/XML_Parser
  */
 
 /**
@@ -79,25 +95,29 @@ define('XML_PARSER_ERROR_REMOTE', 205);
  * - From revision 1.17, the function names used by the 'func' mode
  *   are in the format "xmltag_$elem", for example: use "xmltag_name"
  *   to handle the <name></name> tags of your xml file.
- *
- * @category XML
- * @package XML_Parser
- * @author  Stig Bakken <ssb@fast.no>
- * @author  Tomas V.V.Cox <cox@idecnet.com>
- * @author  Stephan Schmidt <schst@php-tools.net>
- * @todo    create XML_Parser_Namespace to parse documents with namespaces
- * @todo    create XML_Parser_Pull
- * @todo    Tests that need to be made:
- *          - mixing character encodings
- *          - a test using all expat handlers
- *          - options (folding, output charset)
  *          - different parsing modes
+ *
+ * @category  XML
+ * @package   XML_Parser
+ * @author    Stig Bakken <ssb@fast.no>
+ * @author    Tomas V.V.Cox <cox@idecnet.com>
+ * @author    Stephan Schmidt <schst@php.net>
+ * @copyright 2002-2008 The PHP Group
+ * @license   http://opensource.org/licenses/bsd-license New BSD License
+ * @version   Release: @package_version@
+ * @link      http://pear.php.net/package/XML_Parser
+ * @todo      create XML_Parser_Namespace to parse documents with namespaces
+ * @todo      create XML_Parser_Pull
+ * @todo      Tests that need to be made:
+ *            - mixing character encodings
+ *            - a test using all expat handlers
+ *            - options (folding, output charset)
  */
 class XML_Parser extends PEAR
 {
     // {{{ properties
 
-   /**
+    /**
      * XML parser handle
      *
      * @var  resource
@@ -164,27 +184,15 @@ class XML_Parser extends PEAR
      */
     var $_handlerObj;
 
-    // }}}
-    // {{{ constructor
-
     /**
-     * Creates an XML parser.
+     * valid encodings
      *
-     * This is needed for PHP4 compatibility, it will
-     * call the constructor, when a new instance is created.
-     *
-     * @param string $srcenc source charset encoding, use NULL (default) to use
-     *                       whatever the document specifies
-     * @param string $mode   how this parser object should work, "event" for
-     *                       startelement/endelement-type events, "func"
-     *                       to have it call functions named after elements
-     * @param string $tgenc  a valid target encoding
+     * @var array
      */
-    function XML_Parser($srcenc = null, $mode = 'event', $tgtenc = null)
-    {
-        XML_Parser::php5__construct($srcenc, $mode, $tgtenc);
-    }
+    var $_validEncodings = array('ISO-8859-1', 'UTF-8', 'US-ASCII');
+
     // }}}
+    // {{{ php5 constructor
 
     /**
      * PHP5 constructor
@@ -194,9 +202,9 @@ class XML_Parser extends PEAR
      * @param string $mode   how this parser object should work, "event" for
      *                       startelement/endelement-type events, "func"
      *                       to have it call functions named after elements
-     * @param string $tgenc  a valid target encoding
+     * @param string $tgtenc a valid target encoding
      */
-    function php5__construct($srcenc = null, $mode = 'event', $tgtenc = null)
+    function __construct($srcenc = null, $mode = 'event', $tgtenc = null)
     {
         $this->PEAR('XML_Parser_Error');
 
@@ -219,14 +227,16 @@ class XML_Parser extends PEAR
      * This method is only needed, when switching to a new
      * mode at a later point.
      *
-     * @access  public
-     * @param   string          mode, either 'func' or 'event'
-     * @return  boolean|object  true on success, PEAR_Error otherwise   
+     * @param string $mode mode, either 'func' or 'event'
+     *
+     * @return boolean|object  true on success, PEAR_Error otherwise
+     * @access public
      */
     function setMode($mode)
     {
         if ($mode != 'func' && $mode != 'event') {
-            $this->raiseError('Unsupported mode given', XML_PARSER_ERROR_UNSUPPORTED_MODE);
+            $this->raiseError('Unsupported mode given', 
+                XML_PARSER_ERROR_UNSUPPORTED_MODE);
         }
 
         $this->mode = $mode;
@@ -243,10 +253,11 @@ class XML_Parser extends PEAR
      * If no object will be set, XML_Parser assumes that you
      * extend this class and handle the events in $this.
      *
-     * @access  public
-     * @param   object      object to handle the events
-     * @return  boolean     will always return true
-     * @since   v1.2.0beta3
+     * @param object &$obj object to handle the events
+     *
+     * @return boolean will always return true
+     * @access public
+     * @since v1.2.0beta3
      */
     function setHandlerObj(&$obj)
     {
@@ -257,7 +268,8 @@ class XML_Parser extends PEAR
     /**
      * Init the element handlers
      *
-     * @access  private
+     * @return mixed
+     * @access private
      */
     function _initHandlers()
     {
@@ -270,21 +282,22 @@ class XML_Parser extends PEAR
         }
         switch ($this->mode) {
 
-            case 'func':
-                xml_set_object($this->parser, $this->_handlerObj);
-                xml_set_element_handler($this->parser, array(&$this, 'funcStartHandler'), array(&$this, 'funcEndHandler'));
-                break;
+        case 'func':
+            xml_set_object($this->parser, $this->_handlerObj);
+            xml_set_element_handler($this->parser, 
+                array(&$this, 'funcStartHandler'), array(&$this, 'funcEndHandler'));
+            break;
 
-            case 'event':
-                xml_set_object($this->parser, $this->_handlerObj);
-                xml_set_element_handler($this->parser, 'startHandler', 'endHandler');
-                break;
-            default:
-                return $this->raiseError('Unsupported mode given', XML_PARSER_ERROR_UNSUPPORTED_MODE);
-                break;
+        case 'event':
+            xml_set_object($this->parser, $this->_handlerObj);
+            xml_set_element_handler($this->parser, 'startHandler', 'endHandler');
+            break;
+        default:
+            return $this->raiseError('Unsupported mode given', 
+                XML_PARSER_ERROR_UNSUPPORTED_MODE);
+            break;
         }
 
-
         /**
          * set additional handlers for character data, entities, etc.
          */
@@ -293,7 +306,7 @@ class XML_Parser extends PEAR
                 $xml_func = 'xml_set_' . $xml_func;
                 $xml_func($this->parser, $method);
             }
-		}
+        }
     }
 
     // {{{ _create()
@@ -307,9 +320,10 @@ class XML_Parser extends PEAR
      * Furthermore it allows us returning an error
      * if something fails.
      *
-     * @access   private
-     * @return   boolean|object     true on success, PEAR_Error otherwise
+     * NOTE: uses '@' error suppresion in this method
      *
+     * @return bool|PEAR_Error true on success, PEAR_Error otherwise
+     * @access private
      * @see xml_parser_create
      */
     function _create()
@@ -321,21 +335,27 @@ class XML_Parser extends PEAR
         }
         if (is_resource($xp)) {
             if ($this->tgtenc !== null) {
-                if (!@xml_parser_set_option($xp, XML_OPTION_TARGET_ENCODING,
-                                            $this->tgtenc)) {
-                    return $this->raiseError('invalid target encoding', XML_PARSER_ERROR_INVALID_ENCODING);
+                if (!@xml_parser_set_option($xp, XML_OPTION_TARGET_ENCODING, 
+                    $this->tgtenc)
+                ) {
+                    return $this->raiseError('invalid target encoding', 
+                        XML_PARSER_ERROR_INVALID_ENCODING);
                 }
             }
             $this->parser = $xp;
-            $result = $this->_initHandlers($this->mode);
+            $result       = $this->_initHandlers($this->mode);
             if ($this->isError($result)) {
                 return $result;
             }
             xml_parser_set_option($xp, XML_OPTION_CASE_FOLDING, $this->folding);
-
             return true;
         }
-        return $this->raiseError('Unable to create XML parser resource.', XML_PARSER_ERROR_NO_RESOURCE);
+        if (!in_array(strtoupper($this->srcenc), $this->_validEncodings)) {
+            return $this->raiseError('invalid source encoding', 
+                XML_PARSER_ERROR_INVALID_ENCODING);
+        }
+        return $this->raiseError('Unable to create XML parser resource.', 
+            XML_PARSER_ERROR_NO_RESOURCE);
     }
 
     // }}}
@@ -353,7 +373,7 @@ class XML_Parser extends PEAR
     function reset()
     {
         $result = $this->_create();
-        if ($this->isError( $result )) {
+        if ($this->isError($result)) {
             return $result;
         }
         return true;
@@ -365,48 +385,53 @@ class XML_Parser extends PEAR
     /**
      * Sets the input xml file to be parsed
      *
-     * @param    string      Filename (full path)
-     * @return   resource    fopen handle of the given file
-     * @throws   XML_Parser_Error
-     * @see      setInput(), setInputString(), parse()
-     * @access   public
+     * @param string $file Filename (full path)
+     *
+     * @return resource fopen handle of the given file
+     * @access public
+     * @throws XML_Parser_Error
+     * @see setInput(), setInputString(), parse()
      */
     function setInputFile($file)
     {
         /**
          * check, if file is a remote file
          */
-        if (eregi('^(http|ftp)://', substr($file, 0, 10))) {
+        if (preg_match('/^(http|ftp):\/\//i', substr($file, 0, 10))) {
             if (!ini_get('allow_url_fopen')) {
-            	return $this->raiseError('Remote files cannot be parsed, as safe mode is enabled.', XML_PARSER_ERROR_REMOTE);
+                return $this->
+                raiseError('Remote files cannot be parsed, as safe mode is enabled.',
+                XML_PARSER_ERROR_REMOTE);
             }
         }
-        
+
         $fp = @fopen($file, 'rb');
         if (is_resource($fp)) {
             $this->fp = $fp;
             return $fp;
         }
-        return $this->raiseError('File could not be opened.', XML_PARSER_ERROR_FILE_NOT_READABLE);
+        return $this->raiseError('File could not be opened.', 
+            XML_PARSER_ERROR_FILE_NOT_READABLE);
     }
 
     // }}}
     // {{{ setInputString()
-    
+
     /**
      * XML_Parser::setInputString()
-     * 
+     *
      * Sets the xml input from a string
-     * 
+     *
      * @param string $data a string containing the XML document
+     *
      * @return null
-     **/
+     */
     function setInputString($data)
     {
         $this->fp = $data;
         return null;
     }
-    
+
     // }}}
     // {{{ setInput()
 
@@ -414,35 +439,35 @@ class XML_Parser extends PEAR
      * Sets the file handle to use with parse().
      *
      * You should use setInputFile() or setInputString() if you
-     * pass a string 
+     * pass a string
      *
-     * @param    mixed  $fp  Can be either a resource returned from fopen(),
-     *                       a URL, a local filename or a string.
-     * @access   public
-     * @see      parse()
-     * @uses     setInputString(), setInputFile()
+     * @param mixed $fp Can be either a resource returned from fopen(),
+     *                  a URL, a local filename or a string.
+     *
+     * @return mixed
+     * @access public
+     * @see parse()
+     * @uses setInputString(), setInputFile()
      */
     function setInput($fp)
     {
         if (is_resource($fp)) {
             $this->fp = $fp;
             return true;
-        }
-        // see if it's an absolute URL (has a scheme at the beginning)
-        elseif (eregi('^[a-z]+://', substr($fp, 0, 10))) {
+        } elseif (preg_match('/^[a-z]+:\/\//i', substr($fp, 0, 10))) {
+            // see if it's an absolute URL (has a scheme at the beginning)
             return $this->setInputFile($fp);
-        }
-        // see if it's a local file
-        elseif (file_exists($fp)) {
+        } elseif (file_exists($fp)) {
+            // see if it's a local file
             return $this->setInputFile($fp);
-        }
-        // it must be a string
-        else {
+        } else {
+            // it must be a string
             $this->fp = $fp;
             return true;
         }
 
-        return $this->raiseError('Illegal input format', XML_PARSER_ERROR_INVALID_INPUT);
+        return $this->raiseError('Illegal input format', 
+            XML_PARSER_ERROR_INVALID_INPUT);
     }
 
     // }}}
@@ -451,8 +476,8 @@ class XML_Parser extends PEAR
     /**
      * Central parsing function.
      *
-     * @return   true|object PEAR error     returns true on success, or a PEAR_Error otherwise
-     * @access   public
+     * @return bool|PEAR_Error returns true on success, or a PEAR_Error otherwise
+     * @access public
      */
     function parse()
     {
@@ -465,7 +490,7 @@ class XML_Parser extends PEAR
         }
         // if $this->fp was fopened previously
         if (is_resource($this->fp)) {
-        
+
             while ($data = fread($this->fp, 4096)) {
                 if (!$this->_parseString($data, feof($this->fp))) {
                     $error = &$this->raiseError();
@@ -473,8 +498,8 @@ class XML_Parser extends PEAR
                     return $error;
                 }
             }
-        // otherwise, $this->fp must be a string
         } else {
+            // otherwise, $this->fp must be a string
             if (!$this->_parseString($this->fp, true)) {
                 $error = &$this->raiseError();
                 $this->free();
@@ -488,9 +513,10 @@ class XML_Parser extends PEAR
 
     /**
      * XML_Parser::_parseString()
-     * 
-     * @param string $data
-     * @param boolean $eof
+     *
+     * @param string $data data
+     * @param bool   $eof  end-of-file flag
+     *
      * @return bool
      * @access private
      * @see parseString()
@@ -499,31 +525,33 @@ class XML_Parser extends PEAR
     {
         return xml_parse($this->parser, $data, $eof);
     }
-    
+
     // }}}
     // {{{ parseString()
 
     /**
      * XML_Parser::parseString()
-     * 
+     *
      * Parses a string.
      *
-     * @param    string  $data XML data
-     * @param    boolean $eof  If set and TRUE, data is the last piece of data sent in this parser
-     * @throws   XML_Parser_Error
-     * @return   Pear Error|true   true on success or a PEAR Error
-     * @see      _parseString()
+     * @param string  $data XML data
+     * @param boolean $eof  If set and TRUE, data is the last piece 
+     *                      of data sent in this parser
+     *
+     * @return bool|PEAR_Error true on success or a PEAR Error
+     * @throws XML_Parser_Error
+     * @see _parseString()
      */
     function parseString($data, $eof = false)
     {
         if (!isset($this->parser) || !is_resource($this->parser)) {
             $this->reset();
         }
-        
+
         if (!$this->_parseString($data, $eof)) {
-           $error = &$this->raiseError();
-           $this->free();
-           return $error;
+            $error = &$this->raiseError();
+            $this->free();
+            return $error;
         }
 
         if ($eof === true) {
@@ -531,12 +559,12 @@ class XML_Parser extends PEAR
         }
         return true;
     }
-    
+
     /**
      * XML_Parser::free()
-     * 
+     *
      * Free the internal resources associated with the parser
-     * 
+     *
      * @return null
      **/
     function free()
@@ -551,53 +579,63 @@ class XML_Parser extends PEAR
         unset($this->fp);
         return null;
     }
-    
+
     /**
      * XML_Parser::raiseError()
-     * 
+     *
      * Throws a XML_Parser_Error
-     * 
+     *
      * @param string  $msg   the error message
      * @param integer $ecode the error message code
-     * @return XML_Parser_Error 
+     *
+     * @return XML_Parser_Error reference to the error object
      **/
-    function &raiseError($msg = null, $ecode = 0,
-                         $mode = null,
-                         $options = null,
-                         $userinfo = null,
-                         $error_class = null,
-                         $skipmsg = false)
+    function &raiseError($msg = NULL, $ecode = NULL, $mode = NULL, $options = NULL, $userinfo = NULL, $error_class = NULL, $skipmsg = false)
     {
         $msg = !is_null($msg) ? $msg : $this->parser;
         $err = new XML_Parser_Error($msg, $ecode);
         return parent::raiseError($err);
     }
-    
+
     // }}}
     // {{{ funcStartHandler()
 
+    /**
+     * derives and calls the Start Handler function
+     *
+     * @param mixed $xp      ??
+     * @param mixed $elem    ??
+     * @param mixed $attribs ??
+     *
+     * @return void
+     */
     function funcStartHandler($xp, $elem, $attribs)
     {
         $func = 'xmltag_' . $elem;
-        if (strchr($func, '.')) {
-            $func = str_replace('.', '_', $func);
-        }
+        $func = str_replace(array('.', '-', ':'), '_', $func);
         if (method_exists($this->_handlerObj, $func)) {
             call_user_func(array(&$this->_handlerObj, $func), $xp, $elem, $attribs);
         } elseif (method_exists($this->_handlerObj, 'xmltag')) {
-            call_user_func(array(&$this->_handlerObj, 'xmltag'), $xp, $elem, $attribs);
+            call_user_func(array(&$this->_handlerObj, 'xmltag'), 
+                $xp, $elem, $attribs);
         }
     }
 
     // }}}
     // {{{ funcEndHandler()
 
+    /**
+     * derives and calls the End Handler function
+     *
+     * @param mixed $xp   ??
+     * @param mixed $elem ??
+     *
+     * @return void
+     */
     function funcEndHandler($xp, $elem)
     {
         $func = 'xmltag_' . $elem . '_';
-        if (strchr($func, '.')) {
-            $func = str_replace('.', '_', $func);
-        }
+        $func = str_replace(array('.', '-', ':'), '_', $func);
         if (method_exists($this->_handlerObj, $func)) {
             call_user_func(array(&$this->_handlerObj, $func), $xp, $elem);
         } elseif (method_exists($this->_handlerObj, 'xmltag_')) {
@@ -609,24 +647,35 @@ class XML_Parser extends PEAR
     // {{{ startHandler()
 
     /**
+     * abstract method signature for Start Handler
      *
+     * @param mixed $xp       ??
+     * @param mixed $elem     ??
+     * @param mixed &$attribs ??
+     *
+     * @return null
      * @abstract
      */
     function startHandler($xp, $elem, &$attribs)
     {
-        return NULL;
+        return null;
     }
 
     // }}}
     // {{{ endHandler()
 
     /**
+     * abstract method signature for End Handler
      *
+     * @param mixed $xp   ??
+     * @param mixed $elem ??
+     *
+     * @return null
      * @abstract
      */
     function endHandler($xp, $elem)
     {
-        return NULL;
+        return null;
     }
 
 
@@ -644,47 +693,56 @@ class XML_Parser extends PEAR
  * - check for XML_Parser error, using is_a( $error, 'XML_Parser_Error' )
  * - messages can be generated from the xml_parser resource
  *
- * @package XML_Parser
- * @access  public
- * @see     PEAR_Error
+ * @category  XML
+ * @package   XML_Parser
+ * @author    Stig Bakken <ssb@fast.no>
+ * @author    Tomas V.V.Cox <cox@idecnet.com>
+ * @author    Stephan Schmidt <schst@php.net>
+ * @copyright 2002-2008 The PHP Group
+ * @license   http://opensource.org/licenses/bsd-license New BSD License
+ * @version   Release: @package_version@
+ * @link      http://pear.php.net/package/XML_Parser
+ * @see       PEAR_Error
  */
 class XML_Parser_Error extends PEAR_Error
 {
     // {{{ properties
 
-   /**
+    /**
     * prefix for all messages
     *
     * @var      string
-    */    
+    */
     var $error_message_prefix = 'XML_Parser: ';
 
     // }}}
     // {{{ constructor()
-   /**
+    /**
     * construct a new error instance
     *
     * You may either pass a message or an xml_parser resource as first
     * parameter. If a resource has been passed, the last error that
     * happened will be retrieved and returned.
     *
+    * @param string|resource $msgorparser message or parser resource
+    * @param integer         $code        error code
+    * @param integer         $mode        error handling
+    * @param integer         $level       error level
+    *
     * @access   public
-    * @param    string|resource     message or parser resource
-    * @param    integer             error code
-    * @param    integer             error handling
-    * @param    integer             error level
-    */    
+    * @todo PEAR CS - can't meet 85char line limit without arg refactoring
+    */
     function XML_Parser_Error($msgorparser = 'unknown error', $code = 0, $mode = PEAR_ERROR_RETURN, $level = E_USER_NOTICE)
     {
         if (is_resource($msgorparser)) {
-            $code = xml_get_error_code($msgorparser);
+            $code        = xml_get_error_code($msgorparser);
             $msgorparser = sprintf('%s at XML input line %d:%d',
-                                   xml_error_string($code),
-                                   xml_get_current_line_number($msgorparser),
-                                   xml_get_current_column_number($msgorparser));
+                xml_error_string($code),
+                xml_get_current_line_number($msgorparser),
+                xml_get_current_column_number($msgorparser));
         }
         $this->PEAR_Error($msgorparser, $code, $mode, $level);
     }
     // }}}
 }
-?>
\ No newline at end of file
+?>
