@@ -21,7 +21,7 @@ class AttachmentState {
 	/**
 	 * The directory in which the session files are created
 	 */
-	private $attachmentdir = "attachments";
+	private $attachmentdir = 'attachments';
 
 	/**
 	 * The State object which refers to the Attachments state
@@ -44,7 +44,7 @@ class AttachmentState {
 	public function AttachmentState()
 	{
 		$this->basedir = TMP_PATH . DIRECTORY_SEPARATOR . $this->attachmentdir;
-		$this->sessiondir = $this->basedir . DIRECTORY_SEPARATOR . $GLOBALS["mapisession"]->getSessionID();
+		$this->sessiondir = $this->basedir . DIRECTORY_SEPARATOR . $GLOBALS['mapisession']->getSessionID();
 
 		$this->state = new State('attachments');
 	}
@@ -61,8 +61,26 @@ class AttachmentState {
 		}
 
 		$this->state->open();
-		$this->files = $this->state->read("files");
-		$this->deleteattachment = $this->state->read("deleteattachment");
+		$this->files = $this->state->read('files');
+		$this->deleteattachment = $this->state->read('deleteattachment');
+	}
+
+	/**
+	 * Checks if any information regarding attachments is stored in this attachment state.
+	 *
+	 * @param String $message_id The unique identifier for referencing the attachments for a single message
+	 * @return Boolean True to indicate if any changes needed to save in message else false
+	 */
+	public function isChangesPending($message_id)
+	{
+		$files = $this->getAttachmentFiles($message_id);
+		$deletedfiles = $this->getDeletedAttachments($message_id);
+
+		if(empty($files) && empty($deletedfiles)) {
+			return false;
+		}
+
+		return true;
 	}
 
 	/**
@@ -102,6 +120,28 @@ class AttachmentState {
 		return $this->getAttachmentFolder() . DIRECTORY_SEPARATOR . mb_basename($filename);
 	}
 
+	/**
+	 * Check if attachment file which belongs to the given $message_id
+	 * and is identified by the given $attachid is an embedded attachment.
+	 * @param String $message_id The unique identifier for referencing the
+	 * attachments for a single message
+	 * @param String $attachid The unique identifier for referencing the
+	 * attachment
+	 * @return Boolean True if attachment is an embedded else false
+	 */
+	public function isEmbeddedAttachment($message_id, $attachid)
+	{
+		$attach = $this->getAttachmentFile($message_id, $attachid);
+
+		if($attach !== false) {
+			if($attach['sourcetype'] === 'embedded') {
+				return true;
+			}
+		}
+
+		return false;
+	}
+
 	/**
 	 * Add a file which was uploaded to the server by moving it to the attachments directory,
 	 * and then register (addAttachmentFile) it.
@@ -149,7 +189,7 @@ class AttachmentState {
 		// Obtain the generated filename
 		$tmpname = mb_basename($filepath);
 
-		// Move the uploaded file to tmpname loaction
+		// Move the uploaded file to tmpname location
 		rename($sourcefile, $filepath);
 
 		$this->addAttachmentFile($message_id, $tmpname, $fileinfo);
@@ -157,6 +197,24 @@ class AttachmentState {
 		return $tmpname;
 	}
 
+	/**
+	 * Add information regarding embedded attachment to attachment state.
+	 *
+	 * @param String $message_id The unique identifier for referencing the
+	 * attachments for a single message
+	 * @param Array $fileinfo The attachment data
+	 * @return The attachment identifier to be used for referencing the file in the tmp folder
+	 */
+	public function addEmbeddedAttachment($message_id, $fileinfo)
+	{
+		// generate a random number to be used as unique id of attachment
+		$tmpname = md5(rand());
+
+		$this->addAttachmentFile($message_id, $tmpname, $fileinfo);
+
+		return $tmpname;
+	}
+
 	/**
 	 * Delete a file which was previously uploaded to the attachments directory,
 	 * this will call removeAttachmentFile to unregister the attachment from the state
@@ -320,18 +378,23 @@ class AttachmentState {
 	 */
 	public function close()
 	{
-		$this->state->write("files", $this->files, false);
-		$this->state->write("deleteattachment", $this->deleteattachment, false);
+		$this->state->write('files', $this->files, false);
+		$this->state->write('deleteattachment', $this->deleteattachment, false);
 		$this->state->flush();
 		$this->state->close();
 	}
 
 	/**
 	 * Cleans all old attachments in the attachment directory
+	 * @param Integer $maxLifeTime The maximum allowed age of files in seconds.
 	 */
-	public function clean() {
-		cleanTemp($this->basedir, UPLOADED_ATTACHMENT_MAX_LIFETIME);
+	public function clean($maxLifeTime = UPLOADED_ATTACHMENT_MAX_LIFETIME) {
+		cleanTemp($this->basedir, $maxLifeTime);
+
+		// remove base directory also
+		if(is_dir($this->sessiondir)) {
+			rmdir($this->sessiondir);
+		}
 	}
 }
-
-?>
+?>
\ No newline at end of file
