@@ -548,4 +548,7 @@
 			return ($entryIdObj && $entryIdObj['guid'] == self::STATIC_GUID_CONTACT_PROVIDER);
 		}
 	}
+
+	// Create global entryId object
+	$GLOBALS["entryid"] = new EntryId();
 ?>
