@@ -1,7 +1,7 @@
 <?php
 
 	/**
-     * MAPI session handling
+	 * MAPI session handling
 	 *
 	 * This class handles MAPI authentication and stores
 	 * 
@@ -9,6 +9,12 @@
 	 */
 	class MAPISession
 	{
+		/**
+		 * @var sessionid The session id which is used to
+		 * identify the session
+		 */
+		var $sessionid;
+
 		/**
 		 * @var resource This holds the MAPI Session
 		 */
@@ -53,9 +59,11 @@
 		
 		/**
 		 * Default constructor
+		 * @param String The sessionid for which this MAPI Session is created
 		 */		 		
-		function MAPISession()
+		function MAPISession($sessionid)
 		{
+			$this->sessionid = $sessionid;
 			$this->session_info = array("auth"=>false);
 			$this->stores = array();
 			$this->defaultstore = 0;
@@ -210,7 +218,16 @@
 		{
 			return array_key_exists("auth",$this->session_info)?$this->session_info["auth"]:false;
 		}
-		
+
+		/**
+		 * Get current session id
+		 * @return string Current session id
+		 */
+		function getSessionID()
+		{
+			return $this->sessionid;
+		}
+
 		/**
 		 * Get current user entryid
 		 * @return string Current user's entryid
