@@ -1,10 +1,15 @@
 <?php
 require_once("class.xmlparser.php");
 
-define("TYPE_PLUGIN", 1);
-define("TYPE_MODULE", 2);
-define("TYPE_CONFIG", 3);
-define("TYPE_NOTIFIER", 4);
+define('TYPE_PLUGIN', 1);
+define('TYPE_MODULE', 2);
+define('TYPE_CONFIG', 3);
+define('TYPE_NOTIFIER', 4);
+
+define('DEPEND_DEPENDS', 1);
+define('DEPEND_REQUIRES', 2);
+define('DEPEND_RECOMMENDS', 3);
+define('DEPEND_SUGGESTS', 4);
 
 /**
  * Managing component for all plugins
@@ -18,9 +23,20 @@ class PluginManager
 	// True if the Plugin framework is enabled
 	var $enabled;
 
+	// The path to the folder which contains the plugins
+	var $pluginpath;
+
+	// The path to the folder which holds the configuration for the plugins
+	// This folder has same structure as $this->pluginpath
+	var $pluginconfigpath;
+
 	// List of all plugins and their data
 	var $plugindata;
 
+	// List of the plugins in the order in which
+	// they should be loaded
+	var $pluginorder;
+
 	/**
 	 * List of all hooks registered by plugins. 
 	 * [eventID][] = plugin
@@ -53,6 +69,7 @@ class PluginManager
 
 	/**
 	 * Mapping for the XML 'load' attribute values
+	 * on the <serverfile>, <clientfile> or <resourcefile> element
 	 * to the corresponding define.
 	 */
 	var $loadMap = Array(
@@ -63,7 +80,7 @@ class PluginManager
 
 	/**
 	 * Mapping for the XML 'type' attribute values
-	 * to the corresponding define.
+	 * on the <serverfile> element to the corresponding define.
 	 */
 	var $typeMap = Array(
 		'plugin' => TYPE_PLUGIN,
@@ -71,18 +88,34 @@ class PluginManager
 		'notifier' => TYPE_NOTIFIER
 	);
 
+	/**
+	 * Mapping for the XML 'type' attribute values
+	 * on the <depends> element to the corresponding define.
+	 */
+	var $dependMap = Array(
+		'depends' => DEPEND_DEPENDS,
+		'requires' => DEPEND_REQUIRES,
+		'recommends' => DEPEND_RECOMMENDS,
+		'suggests' => DEPEND_SUGGESTS
+	);
+
 	/**
 	 * Constructor
 	 */
 	function PluginManager($enable = ENABLE_PLUGINS)
 	{
-		$this->enabled = $enable && defined('PATH_PLUGIN_DIR'); 
+		$this->enabled = $enable && defined('PATH_PLUGIN_DIR');
 		$this->plugindata = Array();
+		$this->pluginorder = Array();
 		$this->hooks = Array();
 		$this->plugins = Array();
 		$this->modules = Array();
 		$this->notifiers = Array();
 		$this->sessionData = false;
+		if ($this->enabled) {
+			$this->pluginpath = PATH_PLUGIN_DIR;
+			$this->pluginconfigpath = PATH_PLUGIN_CONFIG_DIR;
+		}
 	} 
 
 	/**
@@ -114,38 +147,217 @@ class PluginManager
 		// Get the plugindata from the state.
 		$pluginState = new State('plugin');
 		$pluginState->open();
-		$this->plugindata = $pluginState->read("plugindata");
+
+		if (!DEBUG_PLUGINS_DISABLE_CACHE) {
+			$this->plugindata = $pluginState->read("plugindata");
+			$this->pluginorder = $pluginState->read("pluginorder");
+		}
 
 		// If no plugindata has been stored yet, get it from the plugins dir.
-		if(!$this->plugindata || DEBUG_PLUGINS_DISABLE_CACHE){
+		if (!$this->plugindata || !$this->pluginorder) {
 			$disabledPlugins = Array();
 			if (!empty($disabled)) {
 				$disabledPlugins = explode(';', $disabled);
 			}
 
-			$this->plugindata = Array();
-			$pluginsdir = opendir(PATH_PLUGIN_DIR);
-			if($pluginsdir) {
-				while(($plugin = readdir($pluginsdir)) !== false){
-					if ($plugin != '.' && $plugin != '..' && !in_array($plugin, $disabledPlugins)){
-						if(is_dir(PATH_PLUGIN_DIR.'/'.$plugin)){
-							if(is_file(PATH_PLUGIN_DIR.'/'.$plugin.'/manifest.xml')){
-								$this->processPlugin($plugin);
-							}
-						}
-					}
-				}
+			// Read all plugins from the plugins folders.
+			$this->plugindata = $this->readPluginFolder($disabledPlugins);
 
-				closedir($pluginsdir);
-			}
-			// Write the plugindata to the state
+			// Not we update plugindata and pluginorder based on the configured dependencies.
+			// Note that each change to plugindata requires the requirements and dependencies
+			// to be recalculated.
+			while (!$this->pluginorder || !$this->validatePluginRequirements()) {
+				// Generate the order in which the plugins should be loaded,
+				// this uses the $this->plugindata as base.
+				$this->pluginorder = $this->buildPluginDependencyOrder();
+			};
+		}
+
+		// Write the plugindata back to the state
+		if (!DEBUG_PLUGINS_DISABLE_CACHE) {
 			$pluginState->write("plugindata", $this->plugindata);
+			$pluginState->write("pluginorder", $this->pluginorder);
 		}
 
 		// Free the state again.
 		$pluginState->close();
 	}
 
+	/**
+	 * readPluginFolder
+	 *
+	 * Read all subfolders of the directory referenced to by $this->pluginpath,
+	 * for each subdir, we $this->processPlugin it as a plugin.
+	 *
+	 * @param $disabledPlugins Array The list of disabled plugins, the subfolders
+	 * named as any of the strings inside this list will not be processed.
+	 * @returns Array The object containing all the processed plugins. The object is a key-value'
+	 * object where the key is the unique name of the plugin, and the value the parsed data.
+	 */
+	function readPluginFolder($disabledPlugins)
+	{
+		$data = Array();
+
+		$pluginsdir = opendir($this->pluginpath);
+		if ($pluginsdir) {
+			while(($plugin = readdir($pluginsdir)) !== false){
+				if ($plugin != '.' && $plugin != '..' && !in_array($plugin, $disabledPlugins)){
+					if(is_dir($this->pluginpath . DIRECTORY_SEPARATOR . $plugin)){
+						if(is_file($this->pluginpath . DIRECTORY_SEPARATOR . $plugin . DIRECTORY_SEPARATOR . 'manifest.xml')){
+							$processed = $this->processPlugin($plugin);
+							$data[$processed['pluginname']] = $processed;
+						}
+					}
+				}
+			}
+
+			closedir($pluginsdir);
+		}
+
+		return $data;
+	}
+
+	/**
+	 * validatePluginRequirements
+	 *
+	 * Go over the parsed $this->plugindata and check if all requirements are met.
+	 * This means that for each plugin which defined a "depends" or "requires" plugin
+	 * we check if those plugins are present on the system. If some dependencies are
+	 * not met, the plugin is removed from $this->plugindata.
+	 *
+	 * @return boolean False if the $this->plugindata was modified by this function
+	 */
+	function validatePluginRequirements()
+	{
+		$modified = false;
+
+		do {
+			$success = true;
+
+			foreach ($this->plugindata as $pluginname => &$plugin) {
+				// Check if the plugin had any dependencies
+				// declared in the manifest. If not, they are obviously
+				// met. Otherwise we have to check the type of dependencies
+				// which were declared.
+				if ($plugin['dependencies']) {
+
+					// We only care about the 'depends' and 'requires'
+					// dependency types. All others are not blocking.
+					foreach ($plugin['dependencies'][DEPEND_DEPENDS] as &$depends) {
+						if (!$this->pluginExists($depends['plugin'])) {
+							if (DEBUG_PLUGINS) {
+								dump('[PLUGIN ERROR] Plugin "' . $pluginname . '" requires "' . $depends['plugin'] . '" which could not be found');
+							}
+							unset($this->plugindata[$pluginname]);
+							// Indicate failure, as we have removed a plugin, and the requirements
+							// must be rechecked.
+							$success = false;
+							// Indicate that the plugindata was modified.
+							$modified = true;
+						}
+					}
+
+					foreach ($plugin['dependencies'][DEPEND_REQUIRES] as &$depends) {
+						if (!$this->pluginExists($depends['plugin'])) {
+							if (DEBUG_PLUGINS) {
+								dump('[PLUGIN ERROR] Plugin "' . $pluginname . '" requires "' . $depends['plugin'] . '" which could not be found');
+							}
+							unset($this->plugindata[$pluginname]);
+							// Indicate failure, as we have removed a plugin, and the requirements
+							// must be rechecked.
+							$success = false;
+							// Indicate that the plugindata was modified.
+							$modified = true;
+						}
+					}
+				}
+			}
+
+		// If a plugin was removed because of a failed dependency or requirement,
+		// then we have to redo the cycle, because another plugin might have depended
+		// on the removed plugin.
+		} while(!$success);
+
+		return !$modified;
+	}
+
+	/**
+	 * buildPluginDependencyOrder
+	 *
+	 * Go over the parsed $this->plugindata and create a ordered list of the plugins, resembling
+	 * the order in which those plugins should be loaded. This goes over all plugins to read
+	 * the 'dependencies' data and ordering those plugins based on the DEPEND_DEPENDS dependency type.
+	 *
+	 * In case of circular dependencies, the $this->plugindata object might be altered to remove
+	 * the plugin which the broken dependencies.
+	 *
+	 * @return Array The array of plugins in the order of which they should be loaded
+	 */
+	function buildPluginDependencyOrder()
+	{
+		$plugins = array_keys($this->plugindata);
+		$ordered = Array();
+		$failedCount = 0;
+
+		// We are going to keep it quite simple, we keep looping over the $plugins
+		// array until it is empty. Each time we find a plugin for which all dependencies
+		// are met, we can put it on the $ordered list. If we have looped over the list twice,
+		// without updated the $ordered list in any way, then we have found a circular dependency
+		// and we cannot resolve the plugins correctly.
+		while (!empty($plugins)) {
+			$pluginname = array_shift($plugins);
+			$plugin = $this->plugindata[$pluginname];
+			$accepted = true;
+
+			// Go over all dependencies to see if they have been met.
+			if ($plugin['dependencies']) {
+				for ($i = 0, $len = count($plugin['dependencies'][DEPEND_DEPENDS]); $i < $len; $i++) {
+					$dependency = $plugin['dependencies'][DEPEND_DEPENDS][$i];
+					if (array_search($dependency['plugin'], $ordered) === FALSE) {
+						$accepted = false;
+						break;
+					}
+				}
+			}
+
+			if ($accepted) {
+				// The dependencies for this plugin have been met, we can push
+				// the plugin into the tree.
+				$ordered[] = $pluginname;
+				$updated = true;
+
+				// Reset the $failedCount property, this ensures that we can keep
+				// looping because other plugins with previously unresolved dependencies
+				// could possible be resolved.
+				$failedCount = 0;
+			} else {
+				// The dependencies for this plugin have not been met, we push
+				// the plugin back to the list and we will retry later when the
+				// $ordered list contains more items.
+				$plugins[] = $pluginname;
+
+				// Increase the $failedCount property, this prevents that we could go into
+				// an infinite loop when a circular dependency was defined.
+				$failedCount++;
+			}
+
+			// If the $failedCount matches the the number of items in the $plugins array,
+			// it means that all unordered plugins have unmet dependencies. This could only
+			// happen for circular dependencies. In that case we will refuse to load those plugins.
+			if ($failedCount === count($plugins)) {
+				foreach ($plugins as $plugin) {
+					if (DEBUG_PLUGINS) {
+						dump('[PLUGIN ERROR] Circular dependency detected for plugin "' . $plugin . '"');
+					}
+					unset($this->plugindata[$plugin]);
+				}
+				break;
+			}
+		}
+
+		return $ordered;
+	}
+
 	/**
 	 * initPlugins
 	 * 
@@ -166,7 +378,7 @@ class PluginManager
 		}
 
 		// Inlcude the root files of all the plugins and instantiate the plugin
-		foreach($this->plugindata as $plugName => &$plugData){
+		foreach ($this->pluginorder as $plugName) {
 			$pluginClassName = 'Plugin' . $plugName;
 			if(class_exists($pluginClassName)){
 				$this->plugins[$plugName] = new $pluginClassName;
@@ -187,14 +399,15 @@ class PluginManager
 	 * for placing hooks, defining modules, etc. 
 	 * 
 	 * @param $dirname string name of the directory of the plugin
+	 * @return array The plugin data read from the given directory
 	 */
 	function processPlugin($dirname){
 		// Read XML manifest file of plugin
-		$handle = fopen(PATH_PLUGIN_DIR.'/'.$dirname.'/manifest.xml', 'rb');
+		$handle = fopen($this->pluginpath . DIRECTORY_SEPARATOR . $dirname . DIRECTORY_SEPARATOR . 'manifest.xml', 'rb');
 		$xml = '';
 		if($handle){
 			while (!feof($handle)) { 
-				$xml .= fread($handle, 8192);
+				$xml .= fread($handle, 4096);
 			}
 			fclose($handle);
 		}
@@ -203,12 +416,12 @@ class PluginManager
 		if ($plugindata) {
 			// Apply the name to the object
 			$plugindata['pluginname'] = $dirname;
-			$this->plugindata[$dirname] = $plugindata;
 		} else {
 			if (DEBUG_PLUGINS) {
 				dump('[PLUGIN ERROR] Plugin "'.$dirname.'" has an invalid manifest.');
 			}
 		}
+		return $plugindata;
 	}
 
 	/**
@@ -328,7 +541,8 @@ class PluginManager
 	 * @param $data mixed (Optional) Usually an array of data that the callback function can modify.
 	 * @return mixed Data that has been changed by plugins.
 	 */
-	function triggerHook($eventID, $data = Array()){
+	function triggerHook($eventID, $data = Array())
+	{
 		if(isset($this->hooks[ $eventID ]) && is_array($this->hooks[ $eventID ])){
 			foreach($this->hooks[ $eventID ] as $key => $pluginname){
 				$this->plugins[ $pluginname ]->execute($eventID, $data);
@@ -368,16 +582,16 @@ class PluginManager
 			// if-statement must be updated.
 			switch ($file['type']) {
 				case TYPE_CONFIG:
-					$componentfiles['server'][] = PATH_PLUGIN_CONFIG_DIR . '/' . $pluginname . '/' . $file['file'];
+					$componentfiles['server'][] = $this->pluginconfigpath . DIRECTORY_SEPARATOR . $pluginname . DIRECTORY_SEPARATOR . $file['file'];
 					break;
 				case TYPE_PLUGIN:
-					$componentfiles['server'][] = PATH_PLUGIN_DIR . '/' . $pluginname . '/' . $file['file'];
+					$componentfiles['server'][] = $this->pluginpath . DIRECTORY_SEPARATOR . $pluginname . DIRECTORY_SEPARATOR . $file['file'];
 					break;
 				case TYPE_MODULE:
-					$componentfiles['modules'][ $file['module'] ] = PATH_PLUGIN_DIR.'/'.$pluginname.'/'.$file['file'];
+					$componentfiles['modules'][ $file['module'] ] = $this->pluginpath . DIRECTORY_SEPARATOR . $pluginname . DIRECTORY_SEPARATOR . $file['file'];
 					break;
 				case TYPE_NOTIFIER:
-					$componentfiles['notifiers'][ $file['notifier'] ] = PATH_PLUGIN_DIR.'/'.$pluginname.'/'.$file['file'];
+					$componentfiles['notifiers'][ $file['notifier'] ] = $this->pluginpath . DIRECTORY_SEPARATOR . $pluginname . DIRECTORY_SEPARATOR .$file['file'];
 					break;
 			}
 
@@ -409,7 +623,8 @@ class PluginManager
 			'notifiers' => Array()
 		);
 
-		foreach($this->plugindata as $pluginname => &$plugin){
+		foreach ($this->pluginorder as $pluginname) {
+			$plugin = &$this->plugindata[$pluginname];
 			foreach($plugin['components'] as &$component) {
 				if (!empty($component['serverfiles'][$load])) {
 					$componentfiles = $this->getServerFilesForComponent($pluginname, $component, $load);
@@ -456,7 +671,7 @@ class PluginManager
 		$componentfiles = Array();
 
 		foreach ($component['clientfiles'][$load] as &$file) {
-			$componentfiles[] = PATH_PLUGIN_DIR.'/'.$pluginname.'/'.$file['file'];
+			$componentfiles[] = $this->pluginpath . DIRECTORY_SEPARATOR . $pluginname . DIRECTORY_SEPARATOR . $file['file'];
 		}
 		unset($file);
 
@@ -479,7 +694,8 @@ class PluginManager
 	function getClientFiles($load = LOAD_RELEASE){
 		$files = Array();
 
-		foreach($this->plugindata as $pluginname => &$plugin){
+		foreach ($this->pluginorder as $pluginname) {
+			$plugin = &$this->plugindata[$pluginname];
 			foreach($plugin['components'] as &$component) {
 				if (!empty($component['clientfiles'][$load])) {
 					$componentfiles = $this->getClientFilesForComponent($pluginname, $component, $load);
@@ -524,7 +740,7 @@ class PluginManager
 		$componentfiles = Array();
 
 		foreach ($component['resourcefiles'][$load] as &$file) {
-			$componentfiles[] = PATH_PLUGIN_DIR.'/'.$pluginname.'/'.$file['file'];
+			$componentfiles[] = $this->pluginpath . DIRECTORY_SEPARATOR . $pluginname . DIRECTORY_SEPARATOR . $file['file'];
 		}
 		unset($file);
 
@@ -547,7 +763,8 @@ class PluginManager
 	function getResourceFiles($load = LOAD_RELEASE) {
 		$files = Array();
 
-		foreach($this->plugindata as $pluginname => &$plugin){
+		foreach ($this->pluginorder as $pluginname) {
+			$plugin = &$this->plugindata[$pluginname];
 			foreach($plugin['components'] as &$component) {
 				if (!empty($component['resourcefiles'][$load])) {
 					$componentfiles = $this->getResourceFilesForComponent($pluginname, $component, $load);
@@ -580,9 +797,10 @@ class PluginManager
 	function getTranslationFilePaths(){
 		$paths = Array();
 
-		foreach($this->plugindata as $pluginname => &$plugin){
+		foreach ($this->pluginorder as $pluginname) {
+			$plugin = &$this->plugindata[$pluginname];
 			if ($plugin['translationsdir']) {
-				$translationPath =  PATH_PLUGIN_DIR.'/'.$pluginname.'/'.$plugin['translationsdir']['dir'];
+				$translationPath =  $this->pluginpath . DIRECTORY_SEPARATOR . $pluginname . DIRECTORY_SEPARATOR . $plugin['translationsdir']['dir'];
 				if(is_dir($translationPath)){
 					$paths[$pluginname] = $translationPath;
 				}
@@ -603,16 +821,23 @@ class PluginManager
 	 */
 	function extractPluginDataFromXML($xml)
 	{
-		$this->xmlParser = new XMLParser(array('configfile', 'component', 'serverfile', 'clientfile', 'resourcefile'));
+		$this->xmlParser = new XMLParser(array('configfile', 'depends', 'component', 'serverfile', 'clientfile', 'resourcefile'));
 
 		$plugindata = Array(
 			'components' => Array(),
+			'dependencies' => null,
 			'translationsdir' => null
 		);
 
 		// Parse all XML data
 		$data = $this->xmlParser->getData($xml);
 
+		// debug code will be remove later
+		if(is_a($data, 'PEAR_Error')) {
+			var_dump($data->toString());
+			var_dump($xml);
+		}
+
 		// Parse the <plugin> attributes
 		if (isset($data['attributes'])) {
 			if (isset($data['attributes']['version']) && intval($data['attributes']['version']) !== 2) {
@@ -635,6 +860,12 @@ class PluginManager
 			);
 		}
 
+		// Parse the <dependencies> element
+		if (isset($data['dependencies']) && isset($data['dependencies']['depends'])) {
+			$dependencies = $this->getDependenciesInfoFromXML($data['dependencies']['depends']);
+			$plugindata['dependencies'] = $dependencies;
+		}
+
 		// Parse the <translations> element
 		if (isset($data['translations']) && isset($data['translations']['translationsdir'])) {
 			$translations = $this->getTranslationsDirInfoFromXML($data['translations']['translationsdir']);
@@ -740,6 +971,55 @@ class PluginManager
 		return $files;
 	}
 
+	/**
+	 * getDependenciesInfoFromXML
+	 *
+	 * Transform the >depends> element array from the manifest XML to a usable object.
+	 * We support the 'type' attribute which indicates wat type of dependency
+	 * it is.
+	 *
+	 * @param $dependsData array Piece of manifest XML which represents all <depends> nodes
+	 * @return array List of dependency information
+	 */
+	function getDependenciesInfoFromXML($dependsData)
+	{
+		$dependencies = Array(
+			DEPEND_DEPENDS => Array(),
+			DEPEND_REQUIRES => Array(),
+			DEPEND_RECOMMENDS => Array(),
+			DEPEND_SUGGESTS => Array()
+		);
+
+		for ($i = 0, $len = count($dependsData); $i < $len; $i++) {
+			$plugin = false;
+			$type = DEPEND_DEPENDS;	// depends | requires | recommends | suggests
+
+			if (is_string($dependsData[$i])) {
+				$plugin = $dependsData[$i];
+			} elseif(isset($dependsData[$i]['dependsname'])) {
+				$plugin = $dependsData[$i]['dependsname'];
+				if (isset($dependsData[$i]['attributes'])) {
+					if (isset($dependsData[$i]['attributes']['type'])) {
+						$type = $dependsData[$i]['attributes']['type'];
+						$type = $this->dependMap[$type];
+					}
+				}
+			} else {
+				if (DEBUG_PLUGINS) {
+					dump('[PLUGIN ERROR] Plugin manifest contains empty depends declaration');
+				}
+			}
+
+			if ($plugin) {
+				$dependencies[$type][] = Array(
+					'plugin' => $plugin
+				);
+			}
+		}
+
+		return $dependencies;
+	}
+
 	/**
 	 * getServerFileInfoFromXML
 	 * 
@@ -886,7 +1166,7 @@ class PluginManager
 				}
 			} else {
 				if (DEBUG_PLUGINS) {
-					dump('[PLUGIN ERROR] Plugin manifest contains empty clientfile declaration');
+					dump('[PLUGIN ERROR] Plugin manifest contains empty resourcefile declaration');
 				}
 			}
 
