@@ -2,7 +2,7 @@
 	/**
 	 * Server-wide properties class
 	 *
-	 * This class is instantiated only once and therefore initialises all its data structures only once. It 
+	 * This class is instantiated only once and therefore initialises all its data structures only once. It
 	 * is then used throughout the code to retrieve property tags for various purposes.
 	 *
 	 * The main idea is that each returned array contains a mapping
@@ -203,7 +203,7 @@
 
 		/**
 		 * Returns the properties for an appointment which is opened in a dialog.
-		 * @return array properties for an appointment.		 
+		 * @return array properties for an appointment.
 		 */
 		function getAppointmentProperties()
 		{
@@ -225,6 +225,8 @@
 	  			$properties["importance"] = PR_IMPORTANCE;
 	  			$properties["sensitivity"] = PR_SENSITIVITY;
 				$properties["object_type"] = PR_OBJECT_TYPE;
+				$properties["message_size"] = PR_MESSAGE_SIZE;
+				$properties["hasattach"] = PR_HASATTACH;
 
 				$properties["sent_representing_entryid"] = PR_SENT_REPRESENTING_ENTRYID;
 				$properties["sent_representing_name"] = PR_SENT_REPRESENTING_NAME;
@@ -294,7 +296,7 @@
 
 		/**
 		 * Returns the properties for an appointment in the listview.
-		 * @return array properties for an appointment.		 
+		 * @return array properties for an appointment.
 		 */
 		function getAppointmentListProperties()
 		{
@@ -344,6 +346,7 @@
 				$properties["icon_index"] = PR_ICON_INDEX;
 				$properties["message_class"] = PR_MESSAGE_CLASS;
 				$properties["message_flags"] = PR_MESSAGE_FLAGS;
+				$properties["message_size"] = PR_MESSAGE_SIZE;
 				$properties["object_type"] = PR_OBJECT_TYPE;
 				$properties["display_name"] = PR_DISPLAY_NAME;
 				$properties["given_name"] = PR_GIVEN_NAME;
@@ -367,6 +370,7 @@
 				$properties["birthday"] = PR_BIRTHDAY;
 				$properties["wedding_anniversary"] = PR_WEDDING_ANNIVERSARY;
 				$properties["sensitivity"] = PR_SENSITIVITY;
+				$properties["hasattach"] = PR_HASATTACH;
 				$properties["fileas"] = "PT_STRING8:PSETID_Address:0x8005";
 				$properties["fileas_selection"] = "PT_LONG:PSETID_Address:0x8006";
 				$properties["business_address"] = "PT_STRING8:PSETID_Address:0x801b";
@@ -596,10 +600,13 @@
 				$properties["parent_entryid"] = PR_PARENT_ENTRYID;
 				$properties["store_entryid"] = PR_STORE_ENTRYID;
 				$properties["icon_index"] = PR_ICON_INDEX;
+				$properties["object_type"] = PR_OBJECT_TYPE;
 				$properties["message_class"] = PR_MESSAGE_CLASS;
 				$properties["message_flags"] = PR_MESSAGE_FLAGS;
+				$properties["message_size"] = PR_MESSAGE_SIZE;
 				$properties["display_name"] = PR_DISPLAY_NAME;
 				$properties["subject"] = PR_SUBJECT;
+				$properties["hasattach"] = PR_HASATTACH;
 				$properties["fileas"] = "PT_STRING8:PSETID_Address:0x8005";
 				$properties["fileas_selection"] = "PT_LONG:PSETID_Address:0x8006";
 				$properties["dl_name"] = "PT_STRING8:PSETID_Address:0x8053";
@@ -774,7 +781,7 @@
 
 		/**
 		 * Returns the properties for an email when it is being opened
-		 * @return array properties for an email. 
+		 * @return array properties for an email.
 		 */
 		function getMailProperties()
 		{
@@ -882,7 +889,7 @@
 
 		/**
 		 * Returns the properties for an email in the list view.
-		 * @return array properties for an email. 
+		 * @return array properties for an email.
 		 */
 		function getMailListProperties()
 		{
@@ -926,6 +933,7 @@
 				$properties["icon_index"] = PR_ICON_INDEX;
 				$properties["message_class"] = PR_MESSAGE_CLASS;
 				$properties["message_flags"] = PR_MESSAGE_FLAGS;
+				$properties["message_size"] = PR_MESSAGE_SIZE;
 				$properties["last_modification_time"] = PR_LAST_MODIFICATION_TIME;
 				$properties["subject"] = PR_SUBJECT;
 				$properties["creation_time"] = PR_CREATION_TIME;
@@ -970,6 +978,7 @@
 				$properties["icon_index"] = PR_ICON_INDEX;
 				$properties["message_class"] = PR_MESSAGE_CLASS;
 				$properties["message_flags"] = PR_MESSAGE_FLAGS;
+				$properties["message_size"] = PR_MESSAGE_SIZE;
 				$properties["object_type"] = PR_OBJECT_TYPE;
 				$properties["subject"] = PR_SUBJECT;
 				$properties["importance"] = PR_IMPORTANCE;
@@ -1035,7 +1044,6 @@
 
 				$properties["display_cc"] = PR_DISPLAY_CC;
 				$properties["display_to"] = PR_DISPLAY_TO;
-				$properties["message_size"] = PR_MESSAGE_SIZE;
 
 				$this->mapping[$this->storeMapping]['task'] = getPropIdsFromStrings($this->store, $properties);
 			}
@@ -1045,7 +1053,7 @@
 
 		/**
 		 * Returns the properties for a task in the listview.
-		 * @return array properties for a task.		 
+		 * @return array properties for a task.
 		 */
 		function getTaskListProperties()
 		{
@@ -1173,5 +1181,37 @@
 
 			return $this->mapping[$this->storeMapping]['rules'];
 		}
+
+		/**
+		 * Return properties used in restoreitemslistmodule
+		 * @return array properties
+		 */
+		function getRestoreItemListProperties()
+		{
+			$this->Init();
+
+			if (!isset($this->mapping[$this->storeMapping]['restoreitemlist'])) {
+				$properties = array();
+				$properties["display_name"] = PR_DISPLAY_NAME;
+				$properties["deleted_on"] = PR_DELETED_ON;
+				$properties["content_count"] = PR_CONTENT_COUNT;
+				$properties["sender_name"] = PR_SENDER_NAME;
+				$properties["subject"] = PR_SUBJECT;
+				$properties["message_size"] = PR_MESSAGE_SIZE;
+				$properties["message_class"] = PR_MESSAGE_CLASS;
+				$properties["store_entryid"] = PR_STORE_ENTRYID;
+				$properties["parent_entryid"] = PR_PARENT_ENTRYID;
+				$properties["entryid"] = PR_ENTRYID;
+				$properties["object_type"] = PR_OBJECT_TYPE;
+				$properties["icon_index"] = PR_ICON_INDEX;
+				$properties["message_delivery_time"] = PR_MESSAGE_DELIVERY_TIME;
+				$properties["message_flags"] = PR_MESSAGE_FLAGS;
+				$properties["hasattach"] = PR_HASATTACH;
+
+				$this->mapping[$this->storeMapping]['restoreitemlist'] = $properties;
+			}
+
+			return $this->mapping[$this->storeMapping]['restoreitemlist'];
+		}
 }
 ?>
