@@ -242,7 +242,6 @@
 
 				$rows = mapi_table_queryallrows($table, $this->properties);
 
-				$entryIdUtil = new EntryId();
 				for ($i = 0, $len = count($rows); $i < $len; $i++) {
 					$user_data = $rows[$i];
 
@@ -253,7 +252,7 @@
 					$item['display_type'] = $user_data[PR_DISPLAY_TYPE];
 
 					// Test whether the GUID in the entryid is from the Contact Provider
-					if($entryIdUtil->hasContactProviderGUID( bin2hex($user_data[$this->properties['entryid']]) )){
+					if($GLOBALS['entryid']->hasContactProviderGUID( bin2hex($user_data[$this->properties['entryid']]) )){
 						// Use the original_display_name property to fill in the fileas column
 						$item['fileas'] = $user_data[$this->properties['original_display_name']];
 						$item['address_type'] = isset($user_data[$this->properties['address_type']]) ? $user_data[$this->properties['address_type']] : 'SMTP';
