@@ -17,10 +17,9 @@
 		{
 			$this->properties = $GLOBALS['properties']->getAppointmentProperties();
 
-			$this->plaintext = true;
-
 			parent::ItemModule($id, $data);
 
+			$this->plaintext = true;
 			$this->skipCopyProperties = array(
 				$this->properties['goid'],
 				$this->properties['goid2'],
@@ -33,14 +32,33 @@
 		{
 			if($store && $entryid) {
 				$data = array();
+
 				$message = $GLOBALS['operations']->openMessage($store, $entryid);
 
-				// add all standard properties from the series/normal message 
-				$data['item'] = $GLOBALS['operations']->getMessageProps($store, $message, $this->properties, (isset($this->plaintext) && $this->plaintext));
+				if(empty($message)) {
+					return;
+				}
+
+				// Open embedded message if requested
+				$attachNum = !empty($action['attach_num']) ? $action['attach_num'] : false;
+				if($attachNum) {
+					// get message props of sub message
+					$parentMessage = $message;
+					$message = $GLOBALS['operations']->openMessage($store, $entryid, $attachNum);
+
+					if(empty($message)) {
+						return;
+					}
+
+					$data['item'] = $GLOBALS['operations']->getEmbeddedMessageProps($store, $message, $this->properties, $parentMessage, $attachNum);
+				} else {
+					// add all standard properties from the series/normal message 
+					$data['item'] = $GLOBALS['operations']->getMessageProps($store, $message, $this->properties, $this->plaintext);
+				}
 
 				// if appointment is recurring then only we should get properties of occurence if basedate is supplied
 				if($data['item']['props']['recurring'] === true) {
-					if(isset($action['basedate']) && $action['basedate']) {
+					if(!empty($action['basedate'])) {
 						// check for occurence/exception
 						$basedate = $action['basedate'];
 
@@ -57,7 +75,7 @@
 							$exception = mapi_attach_openobj($exceptionatt, 0);
 
 							// overwrite properties with the ones from the exception
-							$exceptionProps = $GLOBALS['operations']->getMessageProps($store, $exception, $this->properties, (isset($this->plaintext) && $this->plaintext));
+							$exceptionProps = $GLOBALS['operations']->getMessageProps($store, $exception, $this->properties, $this->plaintext);
 
 							/**
 							 * If recurring item has set reminder to true then
@@ -104,6 +122,7 @@
 
 							// Make sure we are using the passed basedate and not something wrong in the opened item
 							$data['item']['props']['basedate'] = $basedate;
+							$data['item']['attach_num'] = array($exceptionattProps[PR_ATTACH_NUM]);
 						} else if($recur->isDeleteException($basedate)) {
 							// Exception is deleted, should not happen, but if it the case then give error
 							$this->sendFeedback(false,
