@@ -42,11 +42,13 @@
 					$parententryid = $this->getDefaultFolderEntryID($store, '');
 				}
 			}
-			
+
 			if($store) {
 				// Reference to an array which will be filled with PR_ENTRYID, PR_STORE_ENTRYID and PR_PARENT_ENTRYID of the message
 				$messageProps = array();
-				
+				$attachments = !empty($action['attachments']) ? $action['attachments'] : array();
+				$recipients = !empty($action['recipients']) ? $action['recipients'] : array();
+
 				// Set message flags first, because this has to be possible even if the user does not have write permissions
 				if(isset($action['props']) && isset($action['props']['message_flags']) && $entryid) {
 					$msg_action = isset($action['message_action']) ? $action['message_action'] : false;
@@ -55,39 +57,59 @@
 					unset($action['props']['message_flags']);
 				}
 
-				// If there are any more properties left, or there are modified recipients or attachments, then send or save
-				if(!empty($action['props']) || ($entryid && $parententryid && (!empty($action['recipients']) || !empty($action['attachments'])))){
-					$send = false;
-					if(isset($action['message_action']) && isset($action['message_action']['send'])) {
-						$send = $action['message_action']['send'];
-					}
+				$saveChanges = true;
+				$send = false;
 
+				if(isset($action['message_action']) && isset($action['message_action']['send'])) {
+					$send = $action['message_action']['send'];
+				}
+
+				// if we are sending mail then no need to check if anything is modified or not just send the mail
+				if(!$send) {
+					// If there is any property changed then save
+					$saveChanges = !empty($action['props']);
+
+					// Check if we are dealing with drafts and recipients or attachments information is modified
+					if(!$saveChanges) {
+						// check for changes in attachments
+						if(isset($attachments['dialog_attachments'])) {
+							$attachment_state = new AttachmentState();
+							$attachment_state->open();
+							$saveChanges = $attachment_state->isChangesPending($attachments['dialog_attachments']);
+							$attachment_state->close();
+						}
+
+						// check for changes in recipients info
+						$saveChanges = $saveChanges || !empty($recipients);
+					}
+				}
+	
+				// check we should send/save mail
+				if($saveChanges) {
 					$copyAttachments = false;
-					$copyFromMessageId = false;
 					$copyFromStore = false;
-					$copyOnlyInlineAttachments = false;
-					$replyOrigMessageDetails = false;
+					$copyFromMessage = false;
+					$copyInlineAttachmentsOnly = false;
 
 					if(isset($action['message_action']) && isset($action['message_action']['action_type'])) {
-						$actions = array('reply', 'replyall', 'forward', 'edit');
+						$actions = array('reply', 'replyall', 'forward');
 						if (array_search($action['message_action']['action_type'], $actions) !== false) {
 							/**
 							 * we need to copy the original attachments when it is an forwarded message
 							 * OR
 							 * we need to copy ONLY original inline(HIDDEN) attachments when it is reply/replyall message
 							 */
-							$copyFromMessageId = hex2bin($action['message_action']['source_entryid']);
+							$copyFromMessage = hex2bin($action['message_action']['source_entryid']);
 							$copyFromStore = hex2bin($action['message_action']['source_store_entryid']);
-							// Open store (this => $GLOBALS['mapisession'])
-							$copyFromStore = $GLOBALS['mapisession']->openMessageStore($copyFromStore);
+							$copyFromAttachNum = !empty($action['message_action']['source_attach_num']) ? $action['message_action']['source_attach_num'] : false;
 							$copyAttachments = true;
 
-							if ($action['message_action']['action_type'] != 'forward') {
-								$copyOnlyInlineAttachments = true;
-								$replyOrigMessageDetails = array(
-									'source_entryid'=>$action['message_action']['source_entryid'],
-									'source_store_entryid'=>$action['message_action']['source_store_entryid']
-								);
+							// get resources of store and message
+							$copyFromStore = $GLOBALS['mapisession']->openMessageStore($copyFromStore);
+							$copyFromMessage = $GLOBALS['operations']->openMessage($copyFromStore, $copyFromMessage, $copyFromAttachNum);
+
+							if ($action['message_action']['action_type'] === 'reply' || $action['message_action']['action_type'] === 'replyall') {
+								$copyInlineAttachmentsOnly = true;
 							}
 						}
 					}
@@ -95,7 +117,7 @@
 					if($send) {
 						$prop = Conversion::mapXML2MAPI($this->properties, $action['props']);
 
-						$result = $GLOBALS['operations']->submitMessage($store, $entryid, Conversion::mapXML2MAPI($this->properties, $action['props']), $messageProps, isset($action['recipients']) ? $action['recipients'] : array(), isset($action['attachments']) ? $action['attachments'] : array(), $copyFromMessageId, $copyFromStore, $copyAttachments, false, $copyOnlyInlineAttachments, $replyOrigMessageDetails);
+						$result = $GLOBALS['operations']->submitMessage($store, $entryid, Conversion::mapXML2MAPI($this->properties, $action['props']), $messageProps, isset($action['recipients']) ? $action['recipients'] : array(), isset($action['attachments']) ? $action['attachments'] : array(), $copyFromMessage, $copyAttachments, false, $copyInlineAttachmentsOnly);
 						
 						// If draft is sent from the drafts folder, delete notification
 						if($result) {
@@ -113,30 +135,32 @@
 							$this->sendFeedback($result ? true : false, array(), false);
 						}
 					} else {
-						if ($entryid == false && isset($action['attachments']) && isset($action['attachments']['dialog_attachments'])) {
-							$entryid = $state->read('createmail'.$action['attachments']['dialog_attachments']);
-						}
+						$result = $GLOBALS['operations']->saveMessage($store, $entryid, $parententryid, Conversion::mapXML2MAPI($this->properties, $action['props']), $messageProps, isset($action['recipients']) ? $action['recipients'] : array(), isset($action['attachments']) ? $action['attachments'] : array(), array(), $copyFromMessage, $copyAttachments, false, $copyInlineAttachmentsOnly);
 
-						$result = $GLOBALS['operations']->saveMessage($store, $entryid, $parententryid, Conversion::mapXML2MAPI($this->properties, $action['props']), $messageProps, isset($action['recipients']) ? $action['recipients'] : array(), isset($action['attachments']) ? $action['attachments'] : array(), array(), $copyFromMessageId, $copyFromStore, $copyAttachments, false, $copyOnlyInlineAttachments);
-
-						if(isset($action['attachments']) && isset($action['attachments']['dialog_attachments'])) {
-							$state->write('createmail'.$action['attachments']['dialog_attachments'], bin2hex($messageProps[PR_ENTRYID]));
-						}
-						
 						// Update the client with the (new) entryid and parententryid to allow the draft message to be removed when submitting.
-						// Retrieve entryid and parententryid of new mail.
+						// this will also update rowids of attachments which is required when deleting attachments
 						$props = array();
-						$props = mapi_getprops($result, array(PR_ENTRYID, PR_PARENT_ENTRYID, PR_STORE_ENTRYID, PR_MESSAGE_CLASS, PR_OBJECT_TYPE));
+						$props = mapi_getprops($result, array(PR_ENTRYID));
 						$savedMsg = $GLOBALS['operations']->openMessage($store, $props[PR_ENTRYID]);
-						$data = array();
-						$data['item'] = $GLOBALS['operations']->getMessageProps($store, $savedMsg, $this->properties, false);
 
-						$this->addActionData('update', $data);
+						$data = $GLOBALS['operations']->getMessageProps($store, $savedMsg, $this->properties);
+
+						/* 
+						 * html filter modifies body of the message when opening the message
+						 * but we have just saved the message and even if there are changes in body because of html filter
+						 * we shouldn't send updated body to client otherwise it will mark it as changed
+						 */
+						unset($data['props']['body']);
+						unset($data['props']['html_body']);
+						unset($data['props']['isHTML']);
+
+						$this->addActionData('update', array('item' => $data));
 					}
 
 					// Reply/Reply All/Forward Actions (ICON_INDEX & LAST_VERB_EXECUTED)
-					if(isset($action['message_action']) && isset($action['message_action']['action_type']) && $action['message_action']['action_type'] != 'forwardasattachment'
-						&& isset($action['message_action']['source_entryid'])) {
+					// we don't care if we are replying/forwarding from embedded message, as we don't want to save these
+					// proeprties in embedded message
+					if($copyFromMessage && $copyFromStore && empty($action['message_action']['source_attach_num'])) {
 						$props = array();
 						$props[$this->properties['entryid']] = hex2bin($action['message_action']['source_entryid']);
 
@@ -157,13 +181,9 @@
 						}
 						
 						$props[$this->properties['last_verb_execution_time']] = time();
-						
-						// Use the storeid of that belongs to the message_action entryid.
-						// This is in case the message is on another store.
-						$storeOrigMsg = $GLOBALS['mapisession']->openMessageStore(hex2bin($action['message_action']['source_store_entryid']));
 
 						$messageActionProps = array();
-						$messageActionResult = $GLOBALS['operations']->saveMessage($storeOrigMsg, $props[PR_ENTRYID], $parententryid, $props, $messageActionProps);
+						$messageActionResult = $GLOBALS['operations']->saveMessage($copyFromStore, $props[PR_ENTRYID], $parententryid, $props, $messageActionProps);
 
 						if($messageActionResult) {
 							if(isset($messageActionProps[PR_PARENT_ENTRYID])) {
@@ -176,14 +196,14 @@
 				// Feedback for successful save (without send)
 				if($result && !$send) {
 					$GLOBALS['bus']->notify(bin2hex($messageProps[PR_PARENT_ENTRYID]), TABLE_SAVE, $messageProps);
-					$this->sendFeedback(true, array(), true);
 				}
 
 				// Feedback for send
 				if($send) {
 					$this->addActionData('update', array('item' => Conversion::mapMAPI2XML($this->properties, $messageProps)));
-					$this->sendFeedback($result ? true : false, array(), true);
 				}
+
+				$this->sendFeedback($result ? true : false, array(), true);
 			}
 		}
 	}
