@@ -119,7 +119,7 @@
 
 							case "delete":
 								if($store && $parententryid && $entryid) {
-									$this->deleteFolder($store, $parententryid, $entryid);
+									$this->deleteFolder($store, $parententryid, $entryid, $action);
 								}
 								break;
 
@@ -526,7 +526,6 @@
 		 * @param object $store MAPI object of the store
 		 * @param object $folder MAPI object of the folder
 		 * @param array $props the properties to save
-		 * @return boolean true on success or false on failure
 		 */
 		function save($store, $folder, $action)
 		{
@@ -712,18 +711,15 @@
 		 * @param object $store Message Store Object.
 		 * @param string $entryid entryid of the folder.
 		 * @param string $name name of the folder.
-		 * @return boolean true on success or false on failure.
 		 */
 		function modifyFolder($store, $entryid, $name)
 		{
 			$props = array();
-			$result = $GLOBALS["operations"]->modifyFolder($store, $entryid, $name, $props);
+			$result = $GLOBALS["operations"]->renameFolder($store, $entryid, $name, $props);
 
 			if($result && isset($props[PR_ENTRYID])) {
 				$GLOBALS["bus"]->notify(bin2hex($props[PR_ENTRYID]), OBJECT_SAVE, $props);
 			}
-			
-			return $result;
 		}
 		
 		/**
@@ -731,12 +727,13 @@
 		 * @param object $store Message Store Object.
 		 * @param string $parententryid entryid of the parent folder.
 		 * @param string $entryid entryid of the folder.
+		 * @param array $action the action data, sent by the client
 		 * @return boolean true on success or false on failure.
 		 */
-		function deleteFolder($store, $parententryid, $entryid)
+		function deleteFolder($store, $parententryid, $entryid, $action)
 		{
 			$props = array();
-			$result = $GLOBALS["operations"]->deleteFolder($store, $parententryid, $entryid, $props);
+			$result = $GLOBALS["operations"]->deleteFolder($store, $parententryid, $entryid, $props, isset($action['soft_delete']) ? $action['soft_delete'] : false);
 
 			// Indicate if the delete succeedded
 			$this->sendFeedback($result);
@@ -744,14 +741,14 @@
 			if(isset($props[PR_ENTRYID])) {
 				if($result) {
 					$GLOBALS["bus"]->notify(bin2hex($parententryid), OBJECT_SAVE, $props);
-					
+
 					$props = array();
 					$props[PR_PARENT_ENTRYID] = $parententryid;
 
 					$storeprops = mapi_getprops($store, array(PR_ENTRYID, PR_IPM_WASTEBASKET_ENTRYID));
 					$props[PR_STORE_ENTRYID] = $storeprops[PR_ENTRYID];
 					$GLOBALS["bus"]->notify(bin2hex($parententryid), OBJECT_SAVE, $props);
-					
+
 					$props[PR_PARENT_ENTRYID] = $storeprops[PR_IPM_WASTEBASKET_ENTRYID];
 					$GLOBALS["bus"]->notify(bin2hex($parententryid), OBJECT_SAVE, $props);
 				}
@@ -796,9 +793,6 @@
 
 				// Add all response data to Bus
 				$GLOBALS["bus"]->addData($this->getResponseData());
-
-				$GLOBALS["bus"]->notify(bin2hex($props[PR_ENTRYID]), OBJECT_SAVE, $props);
-				$GLOBALS["bus"]->notify(bin2hex($props[PR_ENTRYID]), TABLE_SAVE, $props);
 			}
 		}
 		
@@ -818,9 +812,10 @@
 
 			if($result) {
 				if($moveFolder) {
-
 					try {
-						/* Normally it works well within same store, but entryid gets changed when different stores so we can't use old entryid anymore.
+						/*
+						 * Normally it works well within same store,
+						 * but entryid gets changed when different stores so we can't use old entryid anymore.
 						 * When moving to different store send delete notification.
 						 */
 						$this->addFolderToResponseData($deststore, $sourcefolderentryid, "folders");
@@ -830,7 +825,7 @@
 					} catch (MAPIException $e) {
 						if($e->getCode() == MAPI_E_INVALID_ENTRYID) {
 							// Entryid of the folder might be change after move, so send delete notification for folder.
-							$GLOBALS["bus"]->notify(bin2hex($folderProps[PR_ENTRYID]), OBJECT_DELETE, $props);
+							$GLOBALS["bus"]->notify(bin2hex($props[PR_ENTRYID]), OBJECT_DELETE, $props);
 						}
 					}
 
@@ -911,8 +906,6 @@
 
 				// Add all response data to Bus
 				$GLOBALS["bus"]->addData($this->getResponseData());
-
-				$GLOBALS["bus"]->notify(bin2hex($props[PR_ENTRYID]), OBJECT_SAVE, $props);
 			}
 		}
 	}
