@@ -16,6 +16,11 @@
 		 */
 		var $skipCopyProperties;
 
+		/**
+		 * Indicates that we are supporting only plain text body in the message props
+		 */
+		var $plaintext;
+
 		/**
 		 * Constructor
 		 * @param int $id unique id.
@@ -25,6 +30,8 @@
 		{
 			$this->directBookingMeetingRequest = ENABLE_DIRECT_BOOKING;
 			$this->skipCopyProperties = array();
+			$this->plaintext = false;
+
 			parent::Module($id, $data);
 		}
 		
@@ -307,16 +314,26 @@
 							}
 						} else if($e->getCode() == MAPI_E_STORE_FULL) {
 							$e->setDisplayMessage($this->getOverQuotaMessage($store));
-						}else {
+						} else {
 							$e->setDisplayMessage(_("Could not save message") . ".");
 						}
 						break;
 
-					case "removeFromCalendar":
-						if($e->getCode() == MAPI_E_NO_ACCESS)
-							$e->setDisplayMessage(_("You have insufficient privileges to remove item from the calendar."));
-						else
-							$e->setDisplayMessage(_("Could not remove item from the calendar."));
+					case 'delete':
+						if($e->getCode() == MAPI_E_NO_ACCESS) {
+							if (!empty($action['message_action']['action_type'])) {
+								switch($action['message_action']['action_type'])
+								{
+									case 'removeFromCalendar':
+										$e->setDisplayMessage(_('You have insufficient privileges to remove item from the calendar.'));
+										break;
+								}
+							}
+						}
+
+						if(empty($e->displayMessage)) {
+							$e->setDisplayMessage(_("You have insufficient privileges to save items in this folder") . ".");
+						}
 						break;
 
 					case "resolveConflict":
@@ -365,134 +382,140 @@
 		 */
 		function open($store, $entryid, $action)
 		{
-			if($store && $entryid) {
-				$message = $GLOBALS["operations"]->openMessage($store, $entryid);
-			} else if($entryid) {
-				$message = $GLOBALS["mapisession"]->openMessage($entryid);
-				$messageStoreInfo = mapi_getprops($message, array(PR_STORE_ENTRYID));
-				$store = $GLOBALS["mapisession"]->openMessageStore($messageStoreInfo[PR_STORE_ENTRYID]);
+			$data = array();
+
+			if($entryid) {
+				if($store) {
+					$message = $GLOBALS['operations']->openMessage($store, $entryid);
+				} else {
+					// store is not passed so we need to open the message first to get the store resource
+					$message = $GLOBALS['mapisession']->openMessage($entryid);
+
+					$messageStoreInfo = mapi_getprops($message, array(PR_STORE_ENTRYID));
+					$store = $GLOBALS['mapisession']->openMessageStore($messageStoreInfo[PR_STORE_ENTRYID]);
+				}
 			}
 
 			if(empty($message)) {
 				return;
 			}
 
-			$data = array();
-			if (isset($this->plaintext) && $this->plaintext){
-				$data["item"] = $GLOBALS["operations"]->getMessageProps($store, $message, $this->properties, true);
-			}else{
-				$data["item"] = $GLOBALS["operations"]->getMessageProps($store, $message, $this->properties, false);
-			}
+			// Open embedded message if requested
+			$attachNum = !empty($action['attach_num']) ? $action['attach_num'] : false;
+			if($attachNum) {
+				// get message props of sub message
+				$parentMessage = $message;
+				$message = $GLOBALS['operations']->openMessage($store, $entryid, $attachNum);
 
-			// Check for meeting request, do processing if necessary
-			if(isset($data["item"]['props']["message_class"]) && strpos($data["item"]['props']["message_class"], "IPM.Schedule.Meeting") !== false) {
-				$req = new Meetingrequest($store, $message, $GLOBALS["mapisession"]->getSession(), $this->directBookingMeetingRequest);
+				if(empty($message)) {
+					return;
+				}
 
-				try {
-					if($req->isMeetingRequestResponse()) {
-						if($req->isLocalOrganiser()) {
-							// We received a meeting request response, and we're the delegate/organiser
-							$req->processMeetingRequestResponse();
-						}
-					} else if($req->isMeetingRequest()) {
-						if(!$req->isLocalOrganiser()) {
-							if ($req->isMeetingOutOfDate()) {
-								// we know that meeting is out of date so directly set this properties
-								$data['item']['props']['meetingtype'] = mtgOutOfDate;
-								$data['item']['props']['icon_index'] = 1033;
+				$data['item'] = $GLOBALS['operations']->getEmbeddedMessageProps($store, $message, $this->properties, $parentMessage, $attachNum);
+			} else {
+				// get message props of the message
+				$data['item'] = $GLOBALS['operations']->getMessageProps($store, $message, $this->properties, $this->plaintext);
 
-								// send update to maillistmodule that meeting request is updated with out of date flag
-								$messageProps = mapi_getprops($message, array(PR_ENTRYID, PR_PARENT_ENTRYID, PR_STORE_ENTRYID));
-								$GLOBALS["bus"]->notify(bin2hex($messageProps[PR_PARENT_ENTRYID]), TABLE_SAVE, $messageProps);
-							} else {
-								/**
-								 * if meeting request is not out of date then process it for the first time
-								 * which will create corresponding appointment in the user's calendar
-								 */
-								$req->doAccept(true, false, false);
+				$messageClass = !empty($data['item']['props']['message_class']) ? $data['item']['props']['message_class'] : '';
 
-								// Publish updated free/busy information
-								$GLOBALS["operations"]->publishFreeBusy($store);
+				// Check for meeting request, do processing if necessary
+				if(stripos($messageClass, 'IPM.Schedule.Meeting') !== false) {
+					$req = new Meetingrequest($store, $message, $GLOBALS['mapisession']->getSession(), $this->directBookingMeetingRequest);
+
+					try {
+						if($req->isMeetingRequestResponse()) {
+							if($req->isLocalOrganiser()) {
+								// We received a meeting request response, and we're the delegate/organiser
+								$req->processMeetingRequestResponse();
 							}
+						} else if($req->isMeetingRequest()) {
+							if(!$req->isLocalOrganiser()) {
+								if ($req->isMeetingOutOfDate()) {
+									// we know that meeting is out of date so directly set this properties
+									$data['item']['props']['meetingtype'] = mtgOutOfDate;
+									$data['item']['props']['icon_index'] = 1033;
 
-							// Show user whether meeting request conflict with other appointment or not.
-							$meetingConflicts = $req->isMeetingConflicting();
-
-							/**
-							 * if $meetingConflicts is boolean and true then its a normal meeting.
-							 * if $meetingConflicts is integer then it indicates no of instances of a recurring meeting which conflicts with Calendar.
-							 */
-							if($meetingConflicts !== false) {
-								if ($meetingConflicts === true) {
-									$data['item']['props']['conflictinfo'] = _('Conflicts with another appointment.');
+									// send update to maillistmodule that meeting request is updated with out of date flag
+									$messageProps = mapi_getprops($message, array(PR_ENTRYID, PR_PARENT_ENTRYID, PR_STORE_ENTRYID));
+									$GLOBALS['bus']->notify(bin2hex($messageProps[PR_PARENT_ENTRYID]), TABLE_SAVE, $messageProps);
 								} else {
-									$data['item']['props']['conflictinfo'] = sprintf(ngettext('%s occurrence of this recurring appointment conflicts with other appointment.', '%s occurrences of this recurring appointment conflicts with other appointments.', $meetingConflicts), $meetingConflicts);
+									/**
+									 * if meeting request is not out of date then process it for the first time
+									 * which will create corresponding appointment in the user's calendar
+									 */
+									$req->doAccept(true, false, false);
+
+									// Publish updated free/busy information
+									$GLOBALS['operations']->publishFreeBusy($store);
+								}
+
+								// Show user whether meeting request conflict with other appointment or not.
+								$meetingConflicts = $req->isMeetingConflicting();
+
+								/**
+								 * if $meetingConflicts is boolean and true then its a normal meeting.
+								 * if $meetingConflicts is integer then it indicates no of instances of a recurring meeting which conflicts with Calendar.
+								 */
+								if($meetingConflicts !== false) {
+									if ($meetingConflicts === true) {
+										$data['item']['props']['conflictinfo'] = _('Conflicts with another appointment.');
+									} else {
+										$data['item']['props']['conflictinfo'] = sprintf(ngettext('%s occurrence of this recurring appointment conflicts with other appointment.', '%s occurrences of this recurring appointment conflicts with other appointments.', $meetingConflicts), $meetingConflicts);
+									}
 								}
 							}
+						} else if($req->isMeetingCancellation()) {
+							$req->processMeetingCancellation();
 						}
-					} else if($req->isMeetingCancellation()) {
-						$req->processMeetingCancellation();
-					}
 
-					if($req->isInCalendar()) {
-						$calendarItemProps = $this->getCalendarItemProps($req);
-						if (!empty($calendarItemProps)) {
-							$data['item']['props'] = array_merge($data['item']['props'], $calendarItemProps);
+						if($req->isInCalendar()) {
+							$calendarItemProps = $this->getCalendarItemProps($req);
+							if (!empty($calendarItemProps)) {
+								$data['item']['props'] = array_merge($data['item']['props'], $calendarItemProps);
+							}
+						} else {
+							$data['item']['props']['appointment_not_found'] = true;
+						}
+					} catch (MAPIException $e) {
+						// if quota is exceeded or or we don't have permission to write in calendar folder than ignore the exception.
+						if($e->getCode() !== MAPI_E_STORE_FULL && $e->getCode() !== MAPI_E_NO_ACCESS) {
+							// re-throw the exception if it is not one of quota/calendar permission.
+							throw $e;
 						}
-					} else {
-						$data['item']['props']['appointment_not_found'] = true;
 					}
-				} catch (MAPIException $e) {
-					// if quota is exceded or or we don't have permission to write in calendar folder than ignore the exception.
-					if($e->getCode() !== MAPI_E_STORE_FULL && $e->getCode() !== MAPI_E_NO_ACCESS) {
-						// re-throw the exception if it is not one of quota/calendar permission.
-						throw $e;
+				} else if (stripos($messageClass, 'IPM.TaskRequest') !== false) {
+					$tr = new TaskRequest($store, $message, $GLOBALS['mapisession']->getSession());
+					$properties = $GLOBALS['properties']->getTaskProperties();
+					
+					if($tr->isTaskRequest()) {
+						$tr->processTaskRequest();
+						$task = $tr->getAssociatedTask(false);
+						$taskProps = $GLOBALS['operations']->getMessageProps($store, $task, $properties, true);
+						$data['item'] = $taskProps;
+
+						// notify task folder that new task has been created
+						$GLOBALS['bus']->notify($taskProps['parent_entryid'], TABLE_SAVE, array(
+							PR_ENTRYID => hex2bin($taskProps['entryid']),
+							PR_PARENT_ENTRYID => hex2bin($taskProps['parent_entryid']),
+							PR_STORE_ENTRYID => hex2bin($taskProps['store_entryid'])
+						));
 					}
+					
+					if($tr->isTaskRequestResponse()) {
+						$tr->processTaskResponse();
+						$task = $tr->getAssociatedTask(false);
+
+						$data['item'] = $GLOBALS['operations']->getMessageProps($store, $task, $properties, true);
+					}
+				} else if(stripos($messageClass, 'REPORT.IPM.NOTE.NDR') !== false) {
+					// check if this message is a NDR (mail)message, if so, generate a new body message
+					$data['item']['props']['isHTML'] = false;
+					$data['item']['props']['body'] = $GLOBALS['operations']->getNDRbody($message);
 				}
 			}
 
-			if (isset($data["item"]['props']["message_class"]) && strpos($data["item"]['props']["message_class"], "IPM.TaskRequest") !== false) {
-				$tr = new TaskRequest($store, $message, $GLOBALS["mapisession"]->getSession());
-				$properties = $GLOBALS["properties"]->getTaskProperties();
-				
-				// @FIXME is this code used anywhere?
-				if($tr->isTaskRequest()) {
-					$tr->processTaskRequest();
-					$task = $tr->getAssociatedTask(false);
-					$taskProps = $GLOBALS["operations"]->getMessageProps($store, $task, $properties, true);
-					$data["item"] = $taskProps;
-
-					// notify task folder that new task has been created
-					$GLOBALS["bus"]->notify($taskProps["parent_entryid"]["_content"], TABLE_SAVE, array(
-						PR_ENTRYID => hex2bin($taskProps["entryid"]["_content"]),
-						PR_PARENT_ENTRYID => hex2bin($taskProps["parent_entryid"]["_content"]),
-						PR_STORE_ENTRYID => hex2bin($taskProps["store_entryid"]["_content"])
-					));
-				}
-				
-				if($tr->isTaskRequestResponse()) {
-					$tr->processTaskResponse();
-					$task = $tr->getAssociatedTask(false);
-
-					$data["item"] = $GLOBALS["operations"]->getMessageProps($store, $task, $properties, true);
-				}
-			}
-			
-			// Open embedded message in embedded message in ...
-			if(isset($action["rootentryid"]) && isset($action["attachments"])) {
-				if(isset($action["attachments"]["attach_num"]) && is_array($action["attachments"]["attach_num"])) {
-					$data["item"] = $GLOBALS["operations"]->getEmbeddedMessage($store, $entryid, $this->properties, $action["attachments"]["attach_num"]);
-				}
-			}
-
-			// check if this message is a NDR (mail)message, if so, generate a new body message
-			if(isset($data["item"]["props"]["message_class"]) && strtoupper($data["item"]["props"]["message_class"]) == "REPORT.IPM.NOTE.NDR"){
-				$data["item"]["props"]["isHTML"] = false;
-				$data["item"]["props"]["body"] = $GLOBALS["operations"]->getNDRbody($GLOBALS["operations"]->openMessage($store, $entryid));
-			}
-							
 			// Allowing to hook in just before the data sent away to be sent to the client
-			$GLOBALS['PluginManager']->triggerHook("server.module.itemmodule.open.after", array(
+			$GLOBALS['PluginManager']->triggerHook('server.module.itemmodule.open.after', array(
 				'moduleObject' =>& $this,
 				'store' => $store,
 				'entryid' => $entryid,
@@ -501,10 +524,10 @@
 				'data' =>& $data
 				));
 
-			$this->addActionData("item", $data);
-			$GLOBALS["bus"]->addData($this->getResponseData());
+			$this->addActionData('item', $data);
+			$GLOBALS['bus']->addData($this->getResponseData());
 		}
-		
+
 		/**
 		 * Function which saves an item.
 		 * @param object $store MAPI Message Store Object
@@ -518,38 +541,28 @@
 			$resultFlags = false;
 			
 			if(isset($action["props"])) {
-				if(!$store && !$parententryid) {
-					if(isset($action["props"]["message_class"])) {
-						$store = $GLOBALS["mapisession"]->getDefaultMessageStore();
-						$parententryid = $this->getDefaultFolderEntryID($store, $action["props"]["message_class"]);
+				if(!$store) {
+					$store = $GLOBALS['mapisession']->getDefaultMessageStore();
+				}
+				if(!$parententryid) {
+					if(isset($action['props']['message_class'])) {
+						$parententryid = $this->getDefaultFolderEntryID($store, $action['props']['message_class']);
+					} else {
+						$parententryid = $this->getDefaultFolderEntryID($store, '');
 					}
-				}else if(!$parententryid){
-					if(isset($action["props"]["message_class"]))
-						$parententryid = $this->getDefaultFolderEntryID($store, $action["props"]["message_class"]);
 				}
 
 				if($store && $parententryid) {
 					$props = Conversion::mapXML2MAPI($this->properties, $action["props"]);
 					
-					/*
-					 * Set message flags separately from other properties, because we want to be able
-					 * to mark messages without having write permissions on a store.
-					 * For instance a delegate user should still be able to mark messages as read.
-					 */
-					if(isset($props[PR_MESSAGE_FLAGS])){
-						$resultFlags = $GLOBALS["operations"]->setMessageFlag($store, $entryid, $props[PR_MESSAGE_FLAGS]);
-						unset($props[PR_MESSAGE_FLAGS]);
-					} else {
-						$resultFlags = true;
-					}
-
 					$messageProps = array(); // props returned from saveMessage
-					// Save message if there are any properties left and setting the flags didn't fail
-					if($resultFlags && !empty($props)){
-						$result = $GLOBALS["operations"]->saveMessage($store, $entryid, $parententryid, $props, $messageProps, array(), (isset($action['attachments']) ? $action['attachments'] : array()));
+
+					// Save message
+					if(!empty($props)){
+						$result = $GLOBALS["operations"]->saveMessage($store, $entryid, $parententryid, $props, $messageProps, array(), (!empty($action['attachments']) ? $action['attachments'] : array()));
 					}
 
-					if($result && $resultFlags) {
+					if($result) {
 						$GLOBALS["bus"]->notify(bin2hex($parententryid), TABLE_SAVE, $messageProps);
 
 						$this->addActionData("update", array("item" => Conversion::mapMAPI2XML($this->properties, $messageProps)));
@@ -581,7 +594,7 @@
 				$storeprops = mapi_getprops($store, array(PR_ENTRYID));
 				$props[PR_STORE_ENTRYID] = $storeprops[PR_ENTRYID];
 				
-				$result = $GLOBALS["operations"]->deleteMessages($store, $parententryid, $entryid);
+				$result = $GLOBALS["operations"]->deleteMessages($store, $parententryid, $entryid, isset($action['soft_delete']) ? $action['soft_delete'] : false);
 
 				if($result) {
 					$GLOBALS["bus"]->notify(bin2hex($parententryid), TABLE_DELETE, $props);
@@ -590,36 +603,6 @@
 			}
 		}
 		
-		/**
-		 * Function which sets the PR_MESSAGE_FLAGS property of an item.
-		 * @param object $store MAPI Message Store Object
-		 * @param string $parententryid parent entryid of the message
-		 * @param string $entryid entryid of the message
-		 * @param array $action the action data, sent by the client
-		 * @return boolean true on success or false on failure
-		 */
-		function setReadFlag($store, $parententryid, $entryid, $action)
-		{
-			$result = false;
-			
-			if($store && $parententryid && $entryid) {
-				$flags = MSGFLAG_READ;
-				if(isset($action["props"]) && isset($action["props"]["message_flags"])) {
-					$flags = $action['props']['message_flags'];
-				}
-
-				$props = array();
-
-				$msg_action = isset($action['message_action']) ? $action['message_action'] : false;
-				$result = $GLOBALS["operations"]->setMessageFlag($store, $entryid, $flags, $msg_action, $props);
-
-				if ($result) {
-					$GLOBALS["bus"]->notify(bin2hex($parententryid), TABLE_SAVE, $props);
-				}
-				$this->sendFeedback($result);
-			}
-		}
-				
 		/**
 		 * Function which returns the entryid of a default folder.		 		 		 
 		 * @param object $store MAPI Message Store Object
