@@ -32,7 +32,7 @@
 								$this->set($action["setting"]);
 								break;
 							case "delete":
-								$this->deleteSetting($action["setting"]);
+								$this->delete($action["setting"]);
 								break;
 							default:
 								$this->handleUnknownActionType($actionType);
@@ -49,8 +49,6 @@
 		/**
 		 * Function will retrieve all settings stored in PR_EC_WEBACCESS_SETTINGS_JSON property
 		 * if proeprty is not defined then it will return generate SettingsException but silently ignores it.
-		 *
-		 * @return boolean true if no exception generated else false.
 		 */
 		function retrieveAll($type)
 		{
@@ -58,8 +56,6 @@
 
 			$this->addActionData($type, $data);
 			$GLOBALS["bus"]->addData($this->getResponseData());
-
-			$result = true;
 		}
 
 		/**
@@ -67,27 +63,26 @@
 		 * 
 		 * @param $settings object/array Object containing a $path and $value of the setting
 		 * which must be modified.
-		 * @return boolean returns true if setting is properly saved and no exception is generated else false.
 		 */
 		function set($settings)
 		{
 			if (isset($settings)) {
+				// we will set the settings but wait with saving until the entire batch has been applied.
 				if (is_array($settings)) {
-					// If multiple settings are provided, we will set the settings
-					// but wait with saving until the entire batch has been applied.
 					foreach ($settings as $setting) {
 						if (isset($setting['path']) && isset($setting['value'])) {
 							$GLOBALS['settings']->set($setting['path'], $setting['value']);
 						}
 					}
 				} else if (isset($settings['path']) && isset($settings['value'])) {
-						$GLOBALS['settings']->set($settings['path'], $settings['value']);
+					$GLOBALS['settings']->set($settings['path'], $settings['value']);
 				}
 
+				// Finally save the settings, this can throw exception when it fails saving settings
+				$GLOBALS['settings']->saveSettings();
+
 				// send success notification to client
 				$this->sendFeedback(true);
-
-				$result = true;
 			}
 		}
 
@@ -95,14 +90,12 @@
 		 * Function will delete a setting indicated by setting path.
 		 * 
 		 * @param $path string/array path of the setting that needs to be deleted
-		 * @return boolean returns true if setting is properly deleted and no exception is generated else false.
 		 */
-		function deleteSetting($path)
+		function delete($path)
 		{
 			if(isset($path)) {
+				// we will delete the settings but wait with saving until the entire batch has been applied.
 				if (is_array($path)) {
-					// If multiple settings are provided, we will set the settings
-					// but wait with saving until the entire batch has been applied.
 					foreach ($path as $item) {
 						$GLOBALS['settings']->delete($item);
 					}
@@ -110,6 +103,9 @@
 					$GLOBALS['settings']->delete($path);
 				}
 
+				// Finally save the settings, this can throw exception when it fails saving settings
+				$GLOBALS['settings']->saveSettings();
+
 				// send success notification to client
 				$this->sendFeedback(true);
 			}
