@@ -54,17 +54,6 @@
 		}
 	}
 
-	/**
-	 * Function which replaces some characters to correct XML values.
-	 * @param string @string string which should be converted
-	 * @return string correct XML	 
-	 */	 	
-	function xmlentities($string) {
-		$string = str_replace("\x00", "", $string);
-		$string = preg_replace("/[\x01-\x08\x0b\x0c\x0e-\x1f]+/", "", $string); // remove control chars, they would break the xml, and aren't needed anyway
-		return str_replace ( array ( '&', '"', "'", '<', '>'), array ( '&amp;' , '&quot;', '&apos;' , '&lt;' , '&gt;'), $string );
-	}
-	
 	/**
 	 * Function which checks if an array is an associative array.
 	 * @param array $data array which should be verified
@@ -73,35 +62,7 @@
 	function is_assoc_array($data) {
 		return is_array($data) && !empty($data) && !preg_match('/^\d+$/', implode('', array_keys($data)));
 	}
-	
-	/**
-	 * Function which compares two users on there full name. Used for sorting the user list.
-	 * @param array $a user
-	 * @param array $b user
-	 * @return integer -1 - $a < $b || 0 - equal || 1 - $a > $b
-	 */	 	
-	function cmpUserList($a, $b) {
-		if (strtolower($a["fullname"]) == strtolower($b["fullname"])) {
-			return 0;
-		}
-		
-		return (strtolower($a["fullname"]) < strtolower($b["fullname"])) ? -1 : 1;
-	}
-	
-	/**
-	 * Function which compares two groups on there group name. Used for sorting the group list.
-	 * @param array $a group
-	 * @param array $b group
-	 * @return integer -1 - $a < $b || 0 - equal || 1 - $a > $b
-	 */	 	
-	function cmpGroupList($a, $b) {
-		if (strtolower($a["groupname"]) == strtolower($b["groupname"])) {
-			return 0;
-		}
-		
-		return (strtolower($a["groupname"]) < strtolower($b["groupname"])) ? -1 : 1;
-	}
-	
+
 	/**
 	 * Function which is simular to the php function array_merge_recursive, but this 
 	 * one overwrites duplicates.
@@ -125,43 +86,6 @@
 		return $array1;
 	}
 	
-	/**
-	 * Function which adds a new mail popup on links which are mail addresses in mail body's.
-	 * This function is called in the filter class (it is a preg_replace_callback function)
-	 * @param array $match the information which part of the body is found.
-	 * @return string new mail popup string	 	 	 
-	 */
-	function mailto_newmail($match)
-	{
-		$js_options = "'toolbar=0,scrollbars=1,location=0,status=1,menubar=0,resizable=1,width=780,height=560,top='+((screen.height/2)-280)+',left='+((screen.width/2)-390)";
-		$newMail = array("TO"=>$match[4]);
-
-		/**
-		 * $match[5] will contain whole string of parameters passed in mailto link, we can't actually
-		 * use reg expr to check different parts, so we have to split parameters
-		 */
-		if (!empty($match[5])) {
-			$parameters = explode('&amp;', $match[5]);
-			for($index = 0, $len = count($parameters); $index < $len; $index++) {
-				$param = explode('=', $parameters[$index]);
-				$newMail[strtoupper($param[0])] = $param[1];
-			}
-		}
-
-		// build a string of parameters which will be added in URL
-		$parameterString = "";
-		if(isset($newMail["TO"])) $parameterString .= '&to=' . $newMail['TO'];
-		if(isset($newMail["CC"])) $parameterString .= '&cc=' . $newMail['CC'];
-		if(isset($newMail["BCC"])) $parameterString .= '&bcc=' . $newMail['BCC'];
-		if(isset($newMail["BODY"])) $parameterString .= '&body=' . $newMail['BODY'];
-		if(isset($newMail["SUBJECT"])) $parameterString .= '&subject=' . $newMail['SUBJECT'];
-
-		// 'encode' newMail array
-		$newMailString = bin2hex(serialize($newMail)); 
-		return '<'.$match[1].$match[2].'='.$match[3].'mailto:'.$match[4].(!empty($match[5])?'?'.$match[5]:'').$match[6].' onclick='."\"parent.webclient.openWindow(this, 'createmail', 'index.php?load=dialog&task=createmail_standard" . $parameterString . "'); return false;\"".$match[7].'>';
-	}
-
-
 	function microtime_float() {
 		list($usec, $sec) = explode(" ", microtime());
 		return ((float)$usec + (float)$sec);
@@ -437,37 +361,66 @@
 	// Constants for regular expressions which are used in get method to verify the input string
 	define("ID_REGEX", "/^[a-z0-9_]+$/im");
 	define("STRING_REGEX", "/^[a-z0-9_\s()@]+$/im");
+	define("USERNAME_REGEX", "/^[a-z0-9\-\.\'_@]+$/im");
 	define("ALLOWED_EMAIL_CHARS_REGEX", "/^[-a-z0-9_\.@!#\$%&'\*\+/=\?\^_`\{\|\}~]+$/im");
-	define("TIMESTAMP_REGEX", "/^[0-9]+$/im");
 	define("NUMERIC_REGEX", "/^[0-9]+$/im");
 	// Don't allow "\/:*?"<>|" characters in filename.
 	define("FILENAME_REGEX", "/^[^\/\:\*\?\"\<\>\|\\\]+$/im");
 
 	/**
-	* Function to retrieve a $_GET variable to prevent XSS
-	*
-	* $var = varibale requested
-	* $default = default result when $var doesn't exist
-	* $usequote = if $var must be surrounded by quotes, note that $default isn't surrounded by quotes even if this is set here!
-	* $regex = To prevent unusual hackers attack / validate the values send from client.
-	*/
-	function get($var, $default="", $usequote=false, $regex = false){
+	 * Function to sanitize user input values to prevent XSS attacks
+	 *
+	 * @param Mixed $value value that should be sanitized
+	 * @param Mixed $default default value to return when value is not safe
+	 * @param String $regex regex to validate values based on type of value passed
+	 */
+	function sanitizeValue($value, $default = '', $regex = false)
+	{
 		$result = $default;
-		if (isset($_GET[$var])){
-			$result = addslashes($_GET[$var]);
-			if($regex) {
-				$match = preg_match_all($regex, $result, $matches);
-				if(!$match){
-					$result = false;
-					$usequote = false;
-				}
+
+		$result = addslashes($value);
+		if($regex) {
+			$match = preg_match_all($regex, $result, $matches);
+			if(!$match) {
+				$result = false;
+				$usequote = false;
 			}
-			if ($usequote===true) 
-				$usequote = "'";
-			if ($usequote!==false)
-				$result = $usequote.$result.$usequote;
 		}
+
 		return $result;
 	}
 
-?>
+	/**
+	 * Function to sanitize user input values to prevent XSS attacks
+	 *
+	 * @param String $key key that should be used to get value from $_GET to sanitize value
+	 * @param Mixed $default default value to return when value is not safe
+	 * @param String $regex regex to validate values based on type of value passed
+	 */
+	function sanitizeGetValue($key, $default = '', $regex = false)
+	{
+		// check if value really exists
+		if(isset($_GET[$key])) {
+			return sanitizeValue($_GET[$key], $default, $regex);
+		}
+
+		return $default;
+	}
+
+	/**
+	 * Function to sanitize user input values to prevent XSS attacks
+	 *
+	 * @param String $key key that should be used to get value from $_POST to sanitize value
+	 * @param Mixed $default default value to return when value is not safe
+	 * @param String $regex regex to validate values based on type of value passed
+	 */
+	function sanitizePostValue($key, $default = '', $regex = false)
+	{
+		// check if value really exists
+		if(isset($_POST[$key])) {
+			return sanitizeValue($_POST[$key], $default, $regex);
+		}
+
+		return $default;
+	}
+?>
\ No newline at end of file
