@@ -62,7 +62,7 @@
 	// We will only allow the logon when the sessionid in the GET arguments matches the
 	// sessionid as send in the cookie. Otherwise the cookie was somehow modified in the
 	// browser.
-	$sessionid = get('sessionid', '', false, ID_REGEX);
+	$sessionid = sanitizeGetValue('sessionid', '', ID_REGEX);
 	if ($sessionid === $GLOBALS["mapisession"]->getSessionId()) {
 		// Logon, the username and password are set in the "index.php" file. So whenever
 		// an user enters this file, the username and password whould be set in the $_SESSION
@@ -134,7 +134,7 @@
 				break;
 		}
 
-		echo json_encode($pingTag);
+		echo JSON::Encode($pingTag);
 	} else if ($GLOBALS["mapisession"]->isLoggedOn()) {
 		// Authenticated
 		// Execute request
@@ -151,15 +151,13 @@
 		// Create global settings object
 		$GLOBALS["settings"] = new Settings();
 
-		// Create global entryId object
-		$GLOBALS["entryid"] = new EntryId();
 		// Create global language object
 		$GLOBALS["language"] = new Language();
 		// Set the correct language
 		$GLOBALS["language"]->setLanguage($session_lang);
 
 		// Get the state information for this subsystem
-		$subsystem = get('subsystem', 'anonymous', false, ID_REGEX);
+		$subsystem = sanitizeGetValue('subsystem', 'anonymous', ID_REGEX);
 
 		$state = new State($subsystem);
 		
@@ -233,7 +231,7 @@
 		$GLOBALS["properties"]->reset();
 		$state->write("properties", $GLOBALS["properties"], false);
 
-		// Write al changes to disk
+		// Write all changes to disk
 		$state->flush();
 
 		// You can skip this as well because the lock is freed after the PHP script ends
